package com.ruoyi.framework.config;

import org.redisson.Redisson;
import org.redisson.api.RedissonClient;
import org.redisson.config.Config;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import javax.annotation.PreDestroy;

@Configuration
public class RedissonConfig {

    @Value("${spring.redis.host}")
    private String redisHost;

    @Value("${spring.redis.port}")
    private int redisPort;

    @Value("${spring.redis.password:}")
    private String redisPassword;

    @Value("${spring.redis.database}")
    private int redisDatabase;

    private RedissonClient redissonClient;

    @Bean
    public RedissonClient redissonClient() {
        Config config = new Config();
        if (redisPassword != null && !redisPassword.isEmpty()) {
            config.useSingleServer()
                  .setAddress("redis://" + redisHost + ":" + redisPort)
                  .setPassword(redisPassword)
                  .setDatabase(redisDatabase);
        } else {
            config.useSingleServer()
                  .setAddress("redis://" + redisHost + ":" + redisPort)
                  .setDatabase(redisDatabase);
        }

        this.redissonClient = Redisson.create(config);
        return this.redissonClient;
    }

    @PreDestroy
    public void destroy() {
        if (this.redissonClient != null) {
            this.redissonClient.shutdown();
        }
    }
}
