package com.ruoyi.cultural.controller;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.util.List;

import com.alibaba.excel.EasyExcel;
import com.alibaba.fastjson2.JSONArray;
import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.common.core.domain.entity.SysRole;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.cultural.domain.CulturalQrCode;
import com.ruoyi.cultural.domain.vo.CulturalVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.cultural.domain.Cultural;
import com.ruoyi.cultural.service.ICulturalService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;

import javax.servlet.http.HttpServletResponse;

/**
 * 文创产品Controller
 *
 * @author seeseele
 * @date 2024-07-19
 */
@Api(tags = "文创产品模块")
@RestController
@RequestMapping("/vrone/culturals")
public class CulturalController extends BaseController {

    private final ICulturalService culturalService;

    public CulturalController(@Qualifier("culturalServiceImplement") ICulturalService culturalService) {
        this.culturalService = culturalService;
    }

    @GetMapping("/list")
    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin,vrone_cultural')")
    @ApiOperation(value = "查询文创产品列表", notes = "传参为cultural（文创产品实体，实体中包含查询条件）")
    public TableDataInfo list(Cultural cultural) {
        startPage();

        for (SysRole role : getLoginUser().getUser().getRoles()) {
            String roleKey = role.getRoleKey();
            if (roleKey.equals("admin") || roleKey.equals("vrone_admin"))
                return getDataTable(culturalService.selectCulturalAllList(cultural));
        }

        cultural.setUserId(getLoginUser().getUserId());
        List<CulturalVo> list = culturalService.selectCulturalList(cultural);
        return getDataTable(list);
    }

    @GetMapping(value = "/{id}")
    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin,vrone_cultural')")
    @ApiOperation(value = "获取文创产品详细信息", notes = "传参为id（文创产品id）")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(culturalService.selectCulturalById(id));
    }


    @PostMapping(value = "/exportQrCodes")
    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin,vrone_cultural')")
    @ApiOperation(value = "导出文创产品二维码excel", notes = "传参为ids（文创产品id数组）")
    public void exportQrCodes(HttpServletResponse response, @RequestBody JSONObject jsonObject) throws IOException {
        JSONArray idsArray = jsonObject.getJSONArray("ids");
        Long[] ids = new Long[idsArray.size()];
        for (int i = 0; i < idsArray.size(); i++) {
            ids[i] = idsArray.getLong(i);
        }

        List<CulturalQrCode> qrList = culturalService.getQrCodeList(ids);

        // 使用 ByteArrayOutputStream 生成文件内容
        try (ByteArrayOutputStream outputStream = new ByteArrayOutputStream()) {
            EasyExcel.write(outputStream, CulturalQrCode.class)
                    .sheet("二维码数据")
                    .doWrite(qrList);
            // 设置响应头
            response.setContentType("application/vnd.openxmlformats-officedocument.spreadsheetml.sheet");
            response.setHeader("Content-Disposition", "attachment; filename=\"culturalQrCodes_" + System.currentTimeMillis() + ".xlsx\"");
            response.setContentLength(outputStream.size());
            // 将 ByteArrayOutputStream 的内容写入 HttpServletResponse 的输出流
            response.getOutputStream().write(outputStream.toByteArray());
            response.getOutputStream().flush();
        }
    }

    @PostMapping
    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin,vrone_cultural')")
    @ApiOperation(value = "新增文创产品", notes = "传参为cultural（文创产品实体）")
    public AjaxResult add(@RequestBody Cultural cultural) {
        if (!culturalService.insertCultural(cultural)) {
            return error("新增失败");
        }

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 201);
        ajaxResult.put("msg", "新增成功");
        return ajaxResult;
    }

    @PutMapping
    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin,vrone_cultural')")
    @ApiOperation(value = "修改文创产品", notes = "传参为cultural（文创产品实体）")
    public AjaxResult edit(@RequestBody Cultural cultural) {
        if (!culturalService.updateCultural(cultural)) {
            return error("修改失败");
        }

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 201);
        ajaxResult.put("msg", "修改成功");
        return ajaxResult;
    }

    @DeleteMapping("/{ids}")
    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin,vrone_cultural')")
    @ApiOperation(value = "删除文创产品", notes = "传参为ids（文创产品id列表）")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(culturalService.deleteCulturalByIds(ids));
    }
}
