package com.ruoyi.cultural.controller;

import java.util.List;

import com.ruoyi.cultural.domain.vo.CulturalLogVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.cultural.domain.CulturalLog;
import com.ruoyi.cultural.service.ICulturalLogService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 文创产品统计Controller
 *
 * @author seeseele
 * @date 2024-07-22
 */
@Api(tags = "文创产品统计模块")
@RestController
@RequestMapping("/vrone/culturalLogs")
public class CulturalLogController extends BaseController {

    private final ICulturalLogService culturalLogService;

    public CulturalLogController(@Qualifier("culturalLogServiceImplement") ICulturalLogService culturalLogService) {
        this.culturalLogService = culturalLogService;
    }

    @GetMapping("/list")
    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin,vrone_cultural')")
    @ApiOperation(value = "查询文创产品统计列表", notes = "传参为culturalLog（文创产品统计实体，实体中包含查询条件）")
    public TableDataInfo list(CulturalLog culturalLog) {
        startPage();
        culturalLog.setUserId(getLoginUser().getUserId());
        List<CulturalLogVo> list = culturalLogService.selectCulturalLogList(culturalLog);
        return getDataTable(list);
    }

    @GetMapping(value = "/{id}")
    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin,vrone_cultural')")
    @ApiOperation(value = "获取文创产品统计详细信息", notes = "传参为id（文创产品统计id）")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(culturalLogService.selectCulturalLogById(id));
    }

    @PostMapping
    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin,vrone_cultural')")
    @ApiOperation(value = "新增文创产品统计", notes = "传参为culturalLog（文创产品统计实体）")
    public AjaxResult add(@RequestBody CulturalLog culturalLog) {
        if (!culturalLogService.insertCulturalLog(culturalLog)) {
            return error("新增失败");
        }

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 201);
        ajaxResult.put("msg", "新增成功");
        return ajaxResult;
    }

    @PutMapping
    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin,vrone_cultural')")
    @ApiOperation(value = "修改文创产品统计统计", notes = "传参为culturalLog（文创产品统计实体）")
    public AjaxResult edit(@RequestBody CulturalLog culturalLog) {
        if (!culturalLogService.updateCulturalLog(culturalLog)) {
            return error("修改失败");
        }

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 201);
        ajaxResult.put("msg", "修改成功");
        return ajaxResult;
    }

}
