package com.ruoyi.cultural.controller;

import java.util.List;

import com.ruoyi.common.core.domain.entity.SysRole;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.cultural.domain.CulturalType;
import com.ruoyi.cultural.service.ICulturalTypeService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 文创产品类别Controller
 *
 * @author seeseele
 * @date 2024-07-19
 */
@Api(tags = "文创产品类别模块")
@RestController
@RequestMapping("/vrone/culturalTypes")
public class CulturalTypeController extends BaseController {

    private final ICulturalTypeService culturalTypeService;

    public CulturalTypeController(@Qualifier("culturalTypeServiceImplement") ICulturalTypeService culturalTypeService) {
        this.culturalTypeService = culturalTypeService;
    }

    @GetMapping("/list")
    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin,vrone_cultural')")
    @ApiOperation(value = "查询文创产品类别列表", notes = "传参为culturalType（文创产品类别实体，实体中包含查询条件）")
    public TableDataInfo list(CulturalType culturalType) {
        startPage();

        for (SysRole role : getLoginUser().getUser().getRoles()) {
            String roleKey = role.getRoleKey();
            if (roleKey.equals("admin") || roleKey.equals("vrone_admin"))
                return getDataTable(culturalTypeService.selectCulturalTypeAllList(culturalType));
        }

        culturalType.setUserId(getLoginUser().getUserId());
        List<CulturalType> list = culturalTypeService.selectCulturalTypeList(culturalType);
        return getDataTable(list);
    }

    @GetMapping(value = "/{id}")
    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin,vrone_cultural')")
    @ApiOperation(value = "获取文创产品类别详细信息", notes = "传参为id（文创产品类别id）")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(culturalTypeService.selectCulturalTypeById(id));
    }

    @PostMapping
    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin,vrone_cultural')")
    @ApiOperation(value = "新增文创产品类别", notes = "传参为culturalType（文创产品类别实体）")
    public AjaxResult add(@RequestBody CulturalType culturalType) {
        if (!culturalTypeService.insertCulturalType(culturalType)) {
            return error("新增失败");
        }

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 201);
        ajaxResult.put("msg", "新增成功");
        return ajaxResult;
    }

    @PutMapping
    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin,vrone_cultural')")
    @ApiOperation(value = "修改文创产品类别", notes = "传参为culturalType（文创产品类别实体）")
    public AjaxResult edit(@RequestBody CulturalType culturalType) {
        if (!culturalTypeService.updateCulturalType(culturalType)) {
            return error("修改失败");
        }

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 201);
        ajaxResult.put("msg", "修改成功");
        return ajaxResult;
    }

    @DeleteMapping("/{ids}")
    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin,vrone_cultural')")
    @ApiOperation(value = "删除文创产品类别", notes = "传参为ids（文创产品类别id列表）")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(culturalTypeService.deleteCulturalTypeByIds(ids));
    }
}
