package com.ruoyi.cultural.service;

import java.util.List;

import com.ruoyi.cultural.domain.Cultural;
import com.ruoyi.cultural.domain.CulturalQrCode;
import com.ruoyi.cultural.domain.vo.CulturalVo;

/**
 * 文创产品Service接口
 *
 * @author seeseele
 * @date 2024-07-19
 */
public interface ICulturalService {

    /**
     * 查询文创产品列表
     *
     * @param cultural 文创产品
     * @return 文创产品集合
     */
    List<CulturalVo> selectCulturalList(Cultural cultural);

    /**
     * 查询所有文创产品列表
     *
     * @param cultural 文创产品
     * @return 文创产品集合
     */
    List<CulturalVo> selectCulturalAllList(Cultural cultural);

    /**
     * 查询文创产品
     *
     * @param id 文创产品主键
     * @return 文创产品
     */
    CulturalVo selectCulturalById(Long id);

    /**
     * 查询文创产品列表
     *
     * @param ids 需要获取的二维码的文创产品主键集合
     * @return 文创产品集合
     */
    List<CulturalQrCode> getQrCodeList(Long[] ids);

    /**
     * 新增文创产品
     *
     * @param cultural 文创产品
     * @return 结果
     */
    boolean insertCultural(Cultural cultural);

    /**
     * 修改文创产品
     *
     * @param cultural 文创产品
     * @return 结果
     */
    boolean updateCultural(Cultural cultural);

    /**
     * 批量删除文创产品
     *
     * @param ids 需要删除的文创产品主键集合
     * @return 结果
     */
    boolean deleteCulturalByIds(Long[] ids);

    /**
     * 删除文创产品信息
     *
     * @param id 文创产品主键
     * @return 结果
     */
    boolean deleteCulturalById(Long id);

}
