package com.ruoyi.cultural.service.impl;

import java.util.ArrayList;
import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.cultural.domain.CulturalType;
import com.ruoyi.cultural.domain.vo.CulturalLogVo;
import com.ruoyi.cultural.mapper.CulturalTypeMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.cultural.mapper.CulturalLogMapper;
import com.ruoyi.cultural.domain.CulturalLog;
import com.ruoyi.cultural.service.ICulturalLogService;

/**
 * 文创产品统计Service业务层处理
 *
 * @author seeseele
 * @date 2024-07-22
 */
@Service("culturalLogServiceImplement")
public class CulturalLogServiceImpl implements ICulturalLogService {

    private final CulturalLogMapper culturalLogMapper;

    private final CulturalTypeMapper culturalTypeMapper;

    public CulturalLogServiceImpl(@Autowired CulturalLogMapper culturalLogMapper,
                                  @Autowired CulturalTypeMapper culturalTypeMapper) {
        this.culturalLogMapper = culturalLogMapper;
        this.culturalTypeMapper = culturalTypeMapper;
    }

    public CulturalLogVo translateToVo(CulturalLog culturalLog) {
        CulturalType culturalType = culturalTypeMapper.selectCulturalTypeById(culturalLog.getTypeId());
        CulturalLogVo culturalLogVo = new CulturalLogVo(culturalLog);
        culturalLogVo.setType(culturalType);
        return culturalLogVo;
    }

    /**
     * 查询文创产品统计列表
     *
     * @param culturalLog 文创产品统计
     * @return 文创产品统计
     */
    @Override
    public List<CulturalLogVo> selectCulturalLogList(CulturalLog culturalLog) {
        List<CulturalLog> list = culturalLogMapper.selectCulturalLogList(culturalLog);
        List<CulturalLogVo> voList = new ArrayList<>();
        for (CulturalLog c : list) {
            voList.add(translateToVo(c));
        }

        return voList;
    }

    /**
     * 查询文创产品统计
     *
     * @param id 文创产品统计主键
     * @return 文创产品统计
     */
    @Override
    public CulturalLogVo selectCulturalLogById(Long id) {
        return translateToVo(culturalLogMapper.selectCulturalLogById(id));
    }

    /**
     * 新增文创产品统计
     *
     * @param culturalLog 文创产品统计
     * @return 结果
     */
    @Override
    public boolean insertCulturalLog(CulturalLog culturalLog) {
        culturalLog.setCreateTime(DateUtils.getNowDate());
        return culturalLogMapper.insertCulturalLog(culturalLog) > 0;
    }

    /**
     * 修改文创产品统计
     *
     * @param culturalLog 文创产品统计
     * @return 结果
     */
    @Override
    public boolean updateCulturalLog(CulturalLog culturalLog) {
        culturalLog.setUpdateTime(DateUtils.getNowDate());
        return culturalLogMapper.updateCulturalLog(culturalLog) > 0;
    }

}
