package com.ruoyi.cultural.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.cultural.mapper.CulturalTypeMapper;
import com.ruoyi.cultural.domain.CulturalType;
import com.ruoyi.cultural.service.ICulturalTypeService;

/**
 * 文创产品类别Service业务层处理
 *
 * @author seeseele
 * @date 2024-07-19
 */
@Service("culturalTypeServiceImplement")
public class CulturalTypeServiceImpl implements ICulturalTypeService {

    private final CulturalTypeMapper culturalTypeMapper;

    public CulturalTypeServiceImpl(@Autowired CulturalTypeMapper culturalTypeMapper) {
        this.culturalTypeMapper = culturalTypeMapper;
    }

    /**
     * 查询文创产品类别列表
     *
     * @param culturalType 文创产品类别
     * @return 文创产品类别
     */
    @Override
    public List<CulturalType> selectCulturalTypeList(CulturalType culturalType) {
        return culturalTypeMapper.selectCulturalTypeList(culturalType);
    }

    /**
     * 查询所有文创产品类别列表
     *
     * @param culturalType 文创产品类别
     * @return 文创产品类别
     */
    @Override
    public List<CulturalType> selectCulturalTypeAllList(CulturalType culturalType) {
        return culturalTypeMapper.selectCulturalTypeAllList(culturalType);
    }

    /**
     * 查询文创产品类别
     *
     * @param id 文创产品类别主键
     * @return 文创产品类别
     */
    @Override
    public CulturalType selectCulturalTypeById(Long id) {
        return culturalTypeMapper.selectCulturalTypeById(id);
    }

    /**
     * 新增文创产品类别
     *
     * @param culturalType 文创产品类别
     * @return 结果
     */
    @Override
    public boolean insertCulturalType(CulturalType culturalType) {
        culturalType.setUserId(SecurityUtils.getUserId());
        culturalType.setCreateTime(DateUtils.getNowDate());
        return culturalTypeMapper.insertCulturalType(culturalType) > 0;
    }

    /**
     * 修改文创产品类别
     *
     * @param culturalType 文创产品类别
     * @return 结果
     */
    @Override
    public boolean updateCulturalType(CulturalType culturalType) {
        culturalType.setUpdateTime(DateUtils.getNowDate());
        return culturalTypeMapper.updateCulturalType(culturalType) > 0;
    }

    /**
     * 批量删除文创产品类别
     *
     * @param ids 需要删除的文创产品类别主键
     * @return 结果
     */
    @Override
    public boolean deleteCulturalTypeByIds(Long[] ids) {
        return culturalTypeMapper.deleteCulturalTypeByIds(ids) > 0;
    }

    /**
     * 删除文创产品类别信息
     *
     * @param id 文创产品类别主键
     * @return 结果
     */
    @Override
    public boolean deleteCulturalTypeById(Long id) {
        return culturalTypeMapper.deleteCulturalTypeById(id) > 0;
    }
}
