package com.ruoyi.project.controller;


import java.util.List;

import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.project.domain.vo.AppVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.project.domain.App;
import com.ruoyi.project.service.IAppService;

/**
 * 展厅Controller
 *
 * @author seeseele
 */
@Api(tags = "展厅模块")
@RestController
@RequestMapping("/vrone/backend/apps")
public class AppController extends BaseController {

    private final IAppService appService;

    public AppController(@Qualifier("appServiceImplement") IAppService appService) {
        this.appService = appService;
    }

    @Anonymous
    @PostMapping("/showList")
    @ApiOperation(value = "查询用于展示的展厅列表", notes = "传参为app（展厅实体，实体中包含查询条件）")
    public AjaxResult showList(@RequestBody App app) {
        List<AppVo> list = appService.selectShowAppVoList(app);

        return success(list);
    }

    @Anonymous
    @GetMapping("/myAppList/{userId}")
    @ApiOperation(value = "根据用户id查询展厅列表", notes = "传参为userId（用户id）")
    public AjaxResult getListByUserId(@PathVariable("userId") Long userId) {
        List<App> list = appService.selectAppListByUserId(userId);

        return success(list);
    }

    @Anonymous
    @GetMapping(value = "/{appId}")
    @ApiOperation(value = "获取展厅详细信息", notes = "传参为appId（展厅id）")
    public AjaxResult getInfo(@PathVariable("appId") Long appId) {
        return success(appService.selectAppVoById(appId));
    }

    @Anonymous
    @PostMapping
    @ApiOperation(value = "新增展厅", notes = "传参为app（展厅实体）")
    public AjaxResult add(@RequestBody App app) {
        if (!appService.insertApp(app)) {
            return error("新增失败");
        }

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 201);
        ajaxResult.put("msg", "新增成功");
        return ajaxResult;
    }

    @Anonymous
    @PutMapping
    @ApiOperation(value = "修改展厅", notes = "传参为app（展厅实体）")
    public AjaxResult edit(@RequestBody App app) {
        if (!appService.updateApp(app)) {
            return error("修改失败");
        }

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 201);
        ajaxResult.put("msg", "修改成功");
        return ajaxResult;
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @GetMapping("/list")
    @ApiOperation(value = "查询展厅列表（管理端）", notes = "传参为app（展厅实体，实体中包含查询条件）")
    public AjaxResult list(App app) {
//        app.setUserId(getLoginUser().getUserId());
        List<AppVo> list = appService.selectAppVoList(app);
        return success(list);
    }

//    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
//    @DeleteMapping("{appId}")
//    @ApiOperation(value = "删除展厅（管理端）", notes = "根据展厅ID删除指定展厅")
//    public AjaxResult remove(@PathVariable Long appId) {
//        return toAjax(appService.deleteAppById(appId));
//    }
}
