package com.ruoyi.project.controller;

import java.util.List;

import cn.dev33.satoken.stp.StpUtil;
import com.ruoyi.common.annotation.Anonymous;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.project.domain.Article;
import com.ruoyi.project.service.IArticleService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;

/**
 * 文章Controller
 *
 * @author seeseele
 * @date 2024-06-09
 */
@Api(tags = "文章模块")
@RestController
@RequestMapping("/vrone/backend/articles")
public class ArticleController extends BaseController {

    private final IArticleService articleService;

    public ArticleController(@Qualifier("articleServiceImplement") IArticleService articleService) {
        this.articleService = articleService;
    }

    @Anonymous
    @GetMapping("/list")
    @ApiOperation(value = "查询文章列表", notes = "传参为article（文章实体，实体中包含查询条件）")
    public AjaxResult list(Article article) {
        List<Article> list = articleService.selectArticleList(article);

        return success(list);
    }

    @Anonymous
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取文章详细信息", notes = "传参为id（文章id）")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        Article article = articleService.selectArticleById(id);
        if (article == null) {
            return error("文章不存在");
        }
        if (StpUtil.isLogin()){
            article.setClickCount(article.getClickCount() + 1L);
            articleService.updateArticle(article);
        }

        return success(article);
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @PostMapping
    @ApiOperation(value = "新增文章", notes = "传参为article（文章实体）")
    public AjaxResult add(@RequestBody Article article) {
        if (!articleService.insertArticle(article)) {
            return error("新增失败");
        }

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 201);
        ajaxResult.put("msg", "新增成功");
        return ajaxResult;
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @PutMapping
    @ApiOperation(value = "修改文章", notes = "传参为article（文章实体）")
    public AjaxResult edit(@RequestBody Article article) {
        if (!articleService.updateArticle(article)) {
            return error("修改失败");
        }

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 201);
        ajaxResult.put("msg", "修改成功");
        return ajaxResult;
    }

    /**
     * 删除文章
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @DeleteMapping("/{id}")
    @ApiOperation(value = "删除文章", notes = "传参为文章id")
    public AjaxResult delete(@PathVariable Long id) {
        if (articleService.deleteArticleById(id)) {
            return AjaxResult.success("删除成功");
        } else {
            return AjaxResult.error("删除失败");
        }
    }
}
