package com.ruoyi.project.controller;

import cn.dev33.satoken.stp.StpUtil;
import com.alibaba.fastjson2.JSONObject;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.project.domain.Cart;
import com.ruoyi.project.service.ICartService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Anonymous
@Api(tags = "购物车模块")
@RestController
@RequestMapping("/vrone/backend/cart")
public class CartController extends BaseController {

    private final ICartService cartService;

    public CartController(
            @Qualifier("cartServiceImplement") ICartService cartService) {
        this.cartService = cartService;
    }

    @PostMapping("/add")
    @ApiOperation(value = "新增商品到购物车", notes = "携带satoken调用，传参为cart(购物车实体)")
    public AjaxResult addToCart(
            @RequestBody Cart cart) throws JsonProcessingException {
        Long currentUserId = StpUtil.getLoginIdAsLong();
        if (!currentUserId.equals(cart.getUserId())){
            return AjaxResult.error("用户id不一致");
        }
        return toAjax(cartService.addToCart(cart));
    }

    @GetMapping("/getCart")
    @ApiOperation(value = "获取购物车商品", notes = "携带satoken调用")
    public AjaxResult getCart() throws JsonProcessingException {
        Long userId = StpUtil.getLoginIdAsLong();
        List<Cart> list = cartService.getCart(userId);
        return AjaxResult.success(list);
    }

    @DeleteMapping("/remove")
    @ApiOperation(value = "删除购物车中的某个商品", notes = "携带satoken调用，传参为商品id")
    public AjaxResult removeFromCart(
            @RequestBody JSONObject jsonObject) {
        Long userId = StpUtil.getLoginIdAsLong();
        Long id = jsonObject.getLong("id");
        return toAjax(cartService.deleteFromCart(userId, id));
    }

    @DeleteMapping("/clear")
    @ApiOperation(value = "清空购物车", notes = "携带satoken调用")
    public AjaxResult clearCart() {
        Long userId = StpUtil.getLoginIdAsLong();
        return toAjax(cartService.clearCart(userId));
    }
}
