package com.ruoyi.project.controller;

import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.project.domain.VrUser;
import com.ruoyi.project.service.IDataPanelService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.math.BigDecimal;
import java.util.stream.Collectors;

@Api(tags = "数据面板模块")
@RestController
@RequestMapping("/vrone/backend/dataPanel")
public class DataPanelController extends BaseController {

    private final IDataPanelService dataPanelService;

    public DataPanelController(
            @Qualifier("dataPanelServiceImplement") IDataPanelService dataPanelService) {
        this.dataPanelService = dataPanelService;
    }

    @Anonymous
    @GetMapping("/list")
    @ApiOperation(value = "获取数据面板")
    public AjaxResult list() {
        JSONObject result = new JSONObject();
        // 历史通知
        result.put("noticeList", dataPanelService.selectNoticeList());
        // 模板热度
        result.put("templateList", dataPanelService.selectTemplateList());
        // 用户充值排行top10
        result.put("userOrderByMoney", dataPanelService
                .selectUserOrderByMoney()
                .stream()
                .limit(10)
                .collect(Collectors.toList()));
        // 用户数量
        result.put("userCount", dataPanelService.selectUserOrderByMoney().size());
        // 新用户数量
        result.put("userCountByToday", dataPanelService.selectUserByToday().size());
        // 总充值额
        result.put("totalMoney", dataPanelService
                .selectUserOrderByMoney()
                .stream()
                .map(VrUser::getTotalMoney)
                .reduce(BigDecimal.ZERO, BigDecimal::add));
        // 今日充值额
        result.put("todayMoney", dataPanelService.selectTodayMoney());

        return success(result);
    }

    @Anonymous
    @GetMapping("/getMoneyListByWeek")
    @ApiOperation(value = "获取七天内的充值额")
    public AjaxResult getMoneyListByWeek() {
        return success(dataPanelService.selectWeekTransactionsList());
    }

    @Anonymous
    @GetMapping("/getMoneyListByMonth")
    @ApiOperation(value = "获取本月内每天的充值额")
    public AjaxResult getMoneyListByMonth() {
        return success(dataPanelService.selectMonthTransactionsList());
    }


}
