package com.ruoyi.project.controller;

import java.util.List;

import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.project.domain.vo.DataSourceVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.project.domain.DataSource;
import com.ruoyi.project.service.IDataSourceService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;

/**
 * 数据源Controller
 *
 * @author seeseele
 * @date 2024-05-09
 */
@Api(tags = "数据源模块")
@RestController
@RequestMapping("/vrone/backend/dataSources")
public class DataSourceController extends BaseController {

    private final IDataSourceService dataSourceService;

    public DataSourceController(@Qualifier("dataSourceServiceImplement") IDataSourceService dataSourceService) {
        this.dataSourceService = dataSourceService;
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @GetMapping("/list")
    @ApiOperation(value = "查询数据源列表（管理端）", notes = "传参为dataSource（数据源实体，实体中包含查询条件）")
    public AjaxResult getList(DataSource dataSource) {
        List<DataSourceVo> list = dataSourceService.selectDataSourceVoList(dataSource);

        return success(list);
    }

    @Anonymous
    @GetMapping("/getListByAppId/{appId}")
    @ApiOperation(value = "根据展厅id查询数据源列表", notes = "传参为appId（展厅id）")
    public AjaxResult getListByAppId(@PathVariable("appId") Long appId) {
        List<DataSourceVo> list = dataSourceService.selectDataSourceVoListByAppId(appId);

        return success(list);
    }

    @Anonymous
    @GetMapping(value = "/{dataSourceId}")
    @ApiOperation(value = "获取数据源详细信息", notes = "传参为dataSourceId（数据源id)")
    public AjaxResult getInfo(@PathVariable("dataSourceId") Long dataSourceId) {
        return success(dataSourceService.selectDataSourceVoById(dataSourceId));
    }

    @Anonymous
    @PostMapping
    @ApiOperation(value = "新增数据源", notes = "传参为dataSource（数据源实体）data（图片/视频/模型数据url，超链接）cover（图片缩略图/视频封面url）")
    public AjaxResult add(@RequestBody JSONObject jsonObject) {
        DataSource dataSource = jsonObject.getObject("dataSource", DataSource.class);
        String data = jsonObject.getString("data");
        String cover = jsonObject.getString("cover");

//        return success();

//        return switch (dataSource.getType().toString()) {
//            case "1" -> toAjax(dataSourceService.insertDataSourceByImageData(dataSource, data, cover));
//            case "2" -> toAjax(dataSourceService.insertDataSourceByVideoData(dataSource, data, cover));
//            case "3" -> toAjax(dataSourceService.insertDataSourceByLinkData(dataSource, data, cover));
//            case "4" -> toAjax(dataSourceService.insertDataSourceByAlbumData(dataSource, data, cover));
//            case "5" -> toAjax(dataSourceService.insertDataSourceByModelData(dataSource, data, cover));
//            default -> AjaxResult.error("没有该数据类型");
//        };
        AjaxResult result;
        switch (dataSource.getType().toString()) {
            case "1":
                result = toAjax(dataSourceService.insertDataSourceByImageData(dataSource, data, cover));
                break;
            case "2":
                result = toAjax(dataSourceService.insertDataSourceByVideoData(dataSource, data, cover));
                break;
            case "3":
                result = toAjax(dataSourceService.insertDataSourceByLinkData(dataSource, data, cover));
                break;
            case "4":
                result = toAjax(dataSourceService.insertDataSourceByAlbumData(dataSource, data, cover));
                break;
            case "5":
                result = toAjax(dataSourceService.insertDataSourceByModelData(dataSource, data, cover));
                break;
            default:
                result = AjaxResult.error("没有该数据类型");
        }
        return result;
    }

    @Anonymous
    @PutMapping
    @ApiOperation(value = "修改数据源", notes = "传参为dataSource（数据源实体）data（图片/视频/模型数据url，超链接）cover（图片缩略图/视频封面url）")
    public AjaxResult edit(@RequestBody JSONObject jsonObject) {
        DataSource dataSource = jsonObject.getObject("dataSource", DataSource.class);
        String data = jsonObject.getString("data");
        String cover = jsonObject.getString("cover");

//        return success();
        AjaxResult result;
        switch (dataSource.getType().toString()) {
            case "1":
                result = toAjax(dataSourceService.updateDataSourceByImageData(dataSource, data, cover));
                break;
            case "2":
                result = toAjax(dataSourceService.updateDataSourceByVideoData(dataSource, data, cover));
                break;
            case "3":
                result = toAjax(dataSourceService.updateDataSourceByLinkData(dataSource, data, cover));
                break;
            case "4":
                result = toAjax(dataSourceService.updateDataSourceByAlbumData(dataSource, data, cover));
                break;
            case "5":
                result = toAjax(dataSourceService.updateDataSourceByModelData(dataSource, data, cover));
                break;
            default:
                result = AjaxResult.error("没有该数据类型");
        }
        return result;
    }

}
