package com.ruoyi.project.controller;

import java.util.List;

import com.ruoyi.common.annotation.Anonymous;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.project.domain.DataType;
import com.ruoyi.project.service.IDataTypeService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;

/**
 * 数据类型Controller
 *
 * @author seeseele
 * @date 2024-05-09
 */
@Api(tags = "数据类型模块")
@RestController
@RequestMapping("/vrone/backend/dataTypes")
public class DataTypeController extends BaseController {

    private final IDataTypeService dataTypeService;

    public DataTypeController(@Qualifier("dataTypeServiceImplement") IDataTypeService dataTypeService) {
        this.dataTypeService = dataTypeService;
    }

    @Anonymous
    @GetMapping("/list")
    @ApiOperation(value = "查询数据类型列表（管理端）", notes = "传参为dataType（数据类型实体，实体中包含查询条件）")
    public AjaxResult list(DataType dataType) {
        List<DataType> list = dataTypeService.selectDataTypeList(dataType);
        return success(list);
    }

    @Anonymous
    @GetMapping(value = "/{dataTypeId}")
    @ApiOperation(value = "获取数据类型详细信息", notes = "传参为dataTypeId（数据类型id）")
    public AjaxResult getInfo(@PathVariable("dataTypeId") Long dataTypeId) {
        return success(dataTypeService.selectDataTypeById(dataTypeId));
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @PostMapping
    @ApiOperation(value = "新增数据类型", notes = "传参为dataType（数据类型实体）")
    public AjaxResult add(@RequestBody DataType dataType) {
        if (!dataTypeService.insertDataType(dataType)) {
            return error("新增失败");
        }

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 201);
        ajaxResult.put("msg", "新增成功");
        return ajaxResult;
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @PutMapping
    @ApiOperation(value = "修改数据类型", notes = "传参为dataType（数据类型实体）")
    public AjaxResult edit(@RequestBody DataType dataType) {
        if (!dataTypeService.updateDataType(dataType)) {
            return error("修改失败");
        }

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 201);
        ajaxResult.put("msg", "修改成功");
        return ajaxResult;
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除数据类型", notes = "传参为ids（数据类型id数组）")
    public AjaxResult remove(@PathVariable Long[] ids) {
        if (!dataTypeService.deleteDataTypeByIds(ids)) {
            return error("删除失败");
        }

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 204);
        ajaxResult.put("msg", "删除成功");
        return ajaxResult;
    }

}
