package com.ruoyi.project.controller;

import java.util.List;

import cn.dev33.satoken.stp.StpUtil;
import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.project.domain.vo.FavoritesVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.project.domain.Favorites;
import com.ruoyi.project.service.IFavoritesService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 收藏夹Controller
 *
 * @author seeseele
 * @date 2025-02-26
 */
@Api(tags = "收藏模块")
@RestController
@RequestMapping("/vrone/backend/favorites")
public class FavoritesController extends BaseController {

    private final IFavoritesService favoritesService;

    public FavoritesController(@Qualifier("favoritesServiceImplement") IFavoritesService favoritesService) {
        this.favoritesService = favoritesService;
    }

    @Anonymous
    @GetMapping("/listByUser")
    @ApiOperation(value = "查询收藏夹列表", notes = "携带satoken调用")
    public AjaxResult listByUser() {
        Long userId = StpUtil.getLoginIdAsLong();
        Favorites favorites = new Favorites();
        favorites.setUserId(userId);
        List<FavoritesVo> list = favoritesService.selectFavoritesList(favorites);
        return success(list);
    }

    @Anonymous
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取收藏夹详细信息", notes = "传参为id（收藏id）")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(favoritesService.selectFavoritesById(id));
    }

    @Anonymous
    @PostMapping
    @ApiOperation(value = "新增收藏夹", notes = "传参为favorites（收藏实体对象）")
    public AjaxResult add(@RequestBody Favorites favorites) {
        return toAjax(favoritesService.insertFavorites(favorites));
    }

    @Anonymous
    @PutMapping
    @ApiOperation(value = "修改收藏夹", notes = "传参为favorites（收藏实体对象）")
    public AjaxResult edit(@RequestBody Favorites favorites) {
        return toAjax(favoritesService.updateFavorites(favorites));
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @GetMapping("/list")
    @ApiOperation(value = "查询收藏夹列表", notes = "")
    public TableDataInfo list(Favorites favorites) {
        startPage();
        List<FavoritesVo> list = favoritesService.selectFavoritesList(favorites);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除收藏夹", notes = "传参为ids（id数组）")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(favoritesService.deleteFavoritesByIds(ids));
    }
}
