package com.ruoyi.project.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import cn.dev33.satoken.stp.StpUtil;
import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.project.domain.vo.FeedbackVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.project.domain.Feedback;
import com.ruoyi.project.service.IFeedbackService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;

/**
 * 用户反馈Controller
 *
 * @author seeseele
 * @date 2025-02-24
 */
@Api(tags = "用户反馈模块")
@RestController
@RequestMapping("/vrone/backend/feedback")
public class FeedbackController extends BaseController {

    private final IFeedbackService feedbackService;

    public FeedbackController(@Qualifier("feedbackServiceImplement") IFeedbackService feedbackService) {
        this.feedbackService = feedbackService;
    }

    @Anonymous
    @PostMapping
    @ApiOperation(value = "新增用户反馈", notes = "传参为feedback（用户反馈实体）")
    public AjaxResult add(@RequestBody JSONObject jsonObject) {
        Feedback feedback = jsonObject.getObject("feedback", Feedback.class);
        return toAjax(feedbackService.insertFeedback(feedback));
    }

    @Anonymous
    @GetMapping("/listByUser")
    @ApiOperation(value = "查询用户反馈列表", notes = "携带satoken调用")
    public TableDataInfo userList() {
        Long userId = StpUtil.getLoginIdAsLong();
        Feedback feedback = new Feedback();
        feedback.setUserId(userId);

        startPage();
        List<FeedbackVo> list = feedbackService.selectFeedbackList(feedback);
        return getDataTable(list);
    }

    @Anonymous
    @GetMapping("/list")
    @ApiOperation(value = "查询用户反馈列表", notes = "传参为feedback（用户反馈实体，实体中包含查询条件）")
    public TableDataInfo list(Feedback feedback) {
        startPage();
        List<FeedbackVo> list = feedbackService.selectFeedbackList(feedback);
        return getDataTable(list);
    }

    @Anonymous
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取用户反馈详细信息", notes = "传参为feedbackId（用户反馈id）")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(feedbackService.selectFeedbackById(id));
    }

    @Anonymous
    @PutMapping
    @ApiOperation(value = "修改用户反馈", notes = "传参为feedback（用户反馈实体）")
    public AjaxResult edit(@RequestBody Feedback feedback) {
        return toAjax(feedbackService.updateFeedback(feedback));
    }

    @Anonymous
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除用户反馈", notes = "传参为ids（用户反馈id数组）")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(feedbackService.deleteFeedbackByIds(ids));
    }
}
