package com.ruoyi.project.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.annotation.Anonymous;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.project.domain.FeedbackType;
import com.ruoyi.project.service.IFeedbackTypeService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 用户反馈类型Controller
 *
 * @author seeseele
 * @date 2025-02-24
 */
@Api(tags = "用户反馈类型模块")
@RestController
@RequestMapping("/vrone/backend/feedbackType")
public class FeedbackTypeController extends BaseController {

    private final IFeedbackTypeService feedbackTypeService;

    public FeedbackTypeController(@Qualifier("feedbackTypeServiceImplement") IFeedbackTypeService feedbackTypeService) {
        this.feedbackTypeService = feedbackTypeService;
    }

    @Anonymous
    @GetMapping("/list")
    @ApiOperation(value = "查询用户反馈类型列表", notes = "传参为feedbackType（用户反馈类型实体，实体中包含查询条件）")
    public TableDataInfo list(FeedbackType feedbackType) {
        startPage();
        List<FeedbackType> list = feedbackTypeService.selectFeedbackTypeList(feedbackType);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @PostMapping("/export")
    @ApiOperation(value = "导出用户反馈类型列表", notes = "传参为feedbackType（用户反馈类型实体，实体中包含导出条件）")
    public void export(HttpServletResponse response, FeedbackType feedbackType) {
        List<FeedbackType> list = feedbackTypeService.selectFeedbackTypeList(feedbackType);
        ExcelUtil<FeedbackType> util = new ExcelUtil<FeedbackType>(FeedbackType.class);
        util.exportExcel(response, list, "用户反馈类型数据");
    }

    @Anonymous
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取用户反馈类型详细信息", notes = "传参为feedbackTypeId（用户反馈类型id）")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(feedbackTypeService.selectFeedbackTypeById(id));
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @PostMapping
    @ApiOperation(value = "新增用户反馈类型", notes = "传参为feedbackType（用户反馈类型实体）")
    public AjaxResult add(@RequestBody FeedbackType feedbackType) {
        return toAjax(feedbackTypeService.insertFeedbackType(feedbackType));
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @PutMapping
    @ApiOperation(value = "修改用户反馈类型", notes = "传参为feedbackType（用户反馈类型实体）")
    public AjaxResult edit(@RequestBody FeedbackType feedbackType) {
        return toAjax(feedbackTypeService.updateFeedbackType(feedbackType));
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除用户反馈类型", notes = "传参为ids（用户反馈类型id数组）")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(feedbackTypeService.deleteFeedbackTypeByIds(ids));
    }
}
