package com.ruoyi.project.controller;

import java.util.List;

import com.ruoyi.common.annotation.Anonymous;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.project.domain.sourceData.ImageData;
import com.ruoyi.project.service.IImageDataService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;

/**
 * 图片数据Controller
 * 
 * @author seeseele
 * @date 2024-05-09
 */
@Api(tags = "图片数据模块")
@RestController
@RequestMapping("/vrone/backend/imageDatas")
public class ImageDataController extends BaseController
{

    private final IImageDataService imageDataService;

    public ImageDataController(@Qualifier("imageDataServiceImplement") IImageDataService iImageDataService){
        this.imageDataService = iImageDataService;
    }

    @Anonymous
    @GetMapping("/list")
    @ApiOperation(value = "查询图片数据列表", notes = "传参为imageData（图片数据实体，实体中包含查询条件）")
    public AjaxResult list(ImageData imageData)
    {
        List<ImageData> list = imageDataService.selectImageDataList(imageData);

        return success(list);
    }

    @Anonymous
    @GetMapping(value = "/{imageDataId}")
    @ApiOperation(value = "获取图片数据详细信息", notes = "传参为imageDataId（图片数据）")
    public AjaxResult getInfo(@PathVariable("imageDataId") Long imageDataId)
    {
        return success(imageDataService.selectImageDataById(imageDataId));
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @PostMapping
    @ApiOperation(value = "新增图片数据", notes = "传参为imageData（图片数据实体）")
    public AjaxResult add(@RequestBody ImageData imageData)
    {
        if (!imageDataService.insertImageData(imageData)){
            return error("新增失败");
        }

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 201);
        ajaxResult.put("msg", "新增成功");
        return ajaxResult;
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @PutMapping
    @ApiOperation(value = "修改图片数据", notes = "传参为imageData（图片数据实体）")
    public AjaxResult edit(@RequestBody ImageData imageData)
    {
        if (!imageDataService.updateImageData(imageData)){
            return error("修改失败");
        }

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 201);
        ajaxResult.put("msg", "修改成功");
        return ajaxResult;
    }

}
