package com.ruoyi.project.controller;

import java.util.List;

import cn.dev33.satoken.stp.StpUtil;
import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.project.domain.vo.NoticeVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.project.domain.Notice;
import com.ruoyi.project.service.INoticeService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;

/**
 * 通知Controller
 *
 * @author seeseele
 * @date 2024-06-09
 */
@Api(tags = "通知模块")
@RestController
@RequestMapping("/vrone/backend/notices")
public class NoticeController extends BaseController {

    private final INoticeService noticeService;

    public NoticeController(@Qualifier("noticeServiceImplement") INoticeService noticeService) {
        this.noticeService = noticeService;
    }

    @Anonymous
    @GetMapping("/myNoticeByUser")
    @ApiOperation(value = "根据用户id查询通知表列表", notes = "携带satoken调用")
    public AjaxResult myNotice() {
        Long userId = StpUtil.getLoginIdAsLong();
        List<NoticeVo> list = noticeService.selectNoticeListByUserId(userId);
        return success(list);
    }

    @Anonymous
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取通知表详细信息", notes = "传参为id（通知id）")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(noticeService.selectNoticeById(id));
    }
    
    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @GetMapping("/list")
    @ApiOperation(value = "查询通知表列表", notes = "传参为notice（通知实体，实体中包含查询条件）")
    public AjaxResult list(Notice notice) {
        List<Notice> list = noticeService.selectNoticeList(notice);
        return success(list);
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @PostMapping
    @ApiOperation(value = "新增通知(所有用户）", notes = "传参为notice（通知实体）")
    public AjaxResult add(@RequestBody Notice notice) {
        if (!noticeService.insertNoticeToAllUser(notice)) {
            return error("新增失败");
        }

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 201);
        ajaxResult.put("msg", "新增成功");
        return ajaxResult;
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @PutMapping
    @ApiOperation(value = "修改通知表", notes = "传参为notice（通知实体）")
    public AjaxResult edit(@RequestBody Notice notice) {
        if (!noticeService.updateNotice(notice)) {
            return error("修改失败");
        }

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 201);
        ajaxResult.put("msg", "修改成功");
        return ajaxResult;
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @DeleteMapping("/{id}")
    @ApiOperation(value = "删除通知", notes = "传参通知id")
    public AjaxResult deleteNotice(@PathVariable("id") Long id) {
        if (noticeService.deleteNotice(id)) {
            return AjaxResult.success("删除成功");
        } else {
            return AjaxResult.error("删除失败");
        }
    }
}
