package com.ruoyi.project.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.annotation.Anonymous;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.project.domain.NoticeLog;
import com.ruoyi.project.service.INoticeLogService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 通知记录Controller
 *
 * @author seeseele
 * @date 2025-02-24
 */
@Api(tags = "通知记录模块")
@RestController
@RequestMapping("/vrone/backend/noticeLog")
public class NoticeLogController extends BaseController {

    private final INoticeLogService noticeLogService;

    public NoticeLogController(@Qualifier("noticeLogServiceImplement") INoticeLogService noticeLogService) {
        this.noticeLogService = noticeLogService;
    }

    @Anonymous
    @GetMapping("/list")
    @ApiOperation(value = "查询通知记录列表", notes = "传参为NoticeLog（通知记录实体，实体中包含查询条件）")
    public TableDataInfo list(NoticeLog noticeLog) {
        startPage();
        List<NoticeLog> list = noticeLogService.selectNoticeLogList(noticeLog);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @PostMapping("/export")
    @ApiOperation(value = "导出通知记录列表", notes = "传参为NoticeLog（通知记录实体，实体中包含导出条件）")
    public void export(HttpServletResponse response, NoticeLog noticeLog) {
        List<NoticeLog> list = noticeLogService.selectNoticeLogList(noticeLog);
        ExcelUtil<NoticeLog> util = new ExcelUtil<NoticeLog>(NoticeLog.class);
        util.exportExcel(response, list, "通知记录数据");
    }

    @Anonymous
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取通知记录详细信息", notes = "传参为NoticeLogId（通知记录id）")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(noticeLogService.selectNoticeLogById(id));
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @PostMapping
    @ApiOperation(value = "新增通知记录", notes = "传参为NoticeLog（通知记录实体）")
    public AjaxResult add(@RequestBody NoticeLog noticeLog) {
        return toAjax(noticeLogService.insertNoticeLog(noticeLog));
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @PutMapping
    @ApiOperation(value = "修改通知记录", notes = "传参为NoticeLog（通知记录实体）")
    public AjaxResult edit(@RequestBody NoticeLog noticeLog) {
        return toAjax(noticeLogService.updateNoticeLog(noticeLog));
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除通知记录", notes = "传参为ids（通知记录id数组）")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(noticeLogService.deleteNoticeLogByIds(ids));
    }
}
