package com.ruoyi.project.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.annotation.Anonymous;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.project.domain.NoticeType;
import com.ruoyi.project.service.INoticeTypeService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 通知类型Controller
 *
 * @author seeseele
 * @date 2025-02-24
 */
@Api(tags = "通知类型模块")
@RestController
@RequestMapping("/vrone/backend/noticeType")
public class NoticeTypeController extends BaseController {

    private final INoticeTypeService noticeTypeService;

    public NoticeTypeController(@Qualifier("noticeTypeServiceImplement") INoticeTypeService noticeTypeService) {
        this.noticeTypeService = noticeTypeService;
    }

    @Anonymous
    @GetMapping("/list")
    @ApiOperation(value = "查询通知类型列表", notes = "传参为noticeType（通知类型实体，实体中包含查询条件）")
    public TableDataInfo list(NoticeType noticeType) {
        startPage();
        List<NoticeType> list = noticeTypeService.selectNoticeTypeList(noticeType);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @PostMapping("/export")
    @ApiOperation(value = "导出通知类型列表", notes = "传参为noticeType（通知类型实体，实体中包含导出条件）")
    public void export(HttpServletResponse response, NoticeType noticeType) {
        List<NoticeType> list = noticeTypeService.selectNoticeTypeList(noticeType);
        ExcelUtil<NoticeType> util = new ExcelUtil<NoticeType>(NoticeType.class);
        util.exportExcel(response, list, "通知类型数据");
    }

    @Anonymous
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取通知类型详细信息", notes = "传参为noticeTypeId（通知类型id）")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(noticeTypeService.selectNoticeTypeById(id));
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @PostMapping
    @ApiOperation(value = "新增通知类型", notes = "传参为noticeType（通知类型实体）")
    public AjaxResult add(@RequestBody NoticeType noticeType) {
        return toAjax(noticeTypeService.insertNoticeType(noticeType));
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @PutMapping
    @ApiOperation(value = "修改通知类型", notes = "传参为noticeType（通知类型实体）")
    public AjaxResult edit(@RequestBody NoticeType noticeType) {
        return toAjax(noticeTypeService.updateNoticeType(noticeType));
    }

    @Anonymous
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除通知类型", notes = "传参为ids（通知类型id数组）")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(noticeTypeService.deleteNoticeTypeByIds(ids));
    }
}
