package com.ruoyi.project.controller;

import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.project.domain.OrderDetails;
import com.ruoyi.project.service.IOrderDetailsService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 订单详情：此用于存储每个订单中包含的具体商品及其相关信息。Controller
 *
 * @author seeseele
 * @date 2025-02-26
 */
@Api(tags = "用户反馈模块")
@RestController
@RequestMapping("/vrone/backend/orderDetails")
public class OrderDetailsController extends BaseController {

    private final IOrderDetailsService orderDetailsService;

    public OrderDetailsController(@Qualifier("orderDetailsServiceImplement") IOrderDetailsService orderDetailsService) {
        this.orderDetailsService = orderDetailsService;
    }

    @Anonymous
    @GetMapping("/list")
    @ApiOperation(value = "查询订单详情", notes = "传参为orderDetails（实体，实体中包含查询条件）")
    public TableDataInfo list(OrderDetails orderDetails) {
        startPage();
        List<OrderDetails> list = orderDetailsService.selectOrderDetailsList(orderDetails);
        return getDataTable(list);
    }

    @Anonymous
    @PostMapping("/export")
    @ApiOperation(value = "导出订单详情", notes = "传参为orderDetails")
    public void export(HttpServletResponse response, OrderDetails orderDetails) {
        List<OrderDetails> list = orderDetailsService.selectOrderDetailsList(orderDetails);
        ExcelUtil<OrderDetails> util = new ExcelUtil<OrderDetails>(OrderDetails.class);
        util.exportExcel(response, list, "订单详情：此用于存储每个订单中包含的具体商品及其相关信息。数据");
    }

    @Anonymous
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取订单详情", notes = "传参为orderDetailsId")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(orderDetailsService.selectOrderDetailsById(id));
    }

    @Anonymous
    @PostMapping
    @ApiOperation(value = "新增订单详情", notes = "传参为orderDetails")
    public AjaxResult add(@RequestBody OrderDetails orderDetails) {
        return toAjax(orderDetailsService.insertOrderDetails(orderDetails));
    }

    @Anonymous
    @PutMapping
    @ApiOperation(value = "修改订单详情", notes = "传参为orderDetails")
    public AjaxResult edit(@RequestBody OrderDetails orderDetails) {
        return toAjax(orderDetailsService.updateOrderDetails(orderDetails));
    }

    @Anonymous
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除订单详情", notes = "传参为ids（用户反馈id数组）")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(orderDetailsService.deleteOrderDetailsByIds(ids));
    }
}
