package com.ruoyi.project.controller;

import java.util.List;

import com.ruoyi.common.annotation.Anonymous;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.project.domain.Scene;
import com.ruoyi.project.service.ISceneService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;

/**
 * 场景Controller
 *
 * @author seeseele
 * @date 2024-05-09
 */
@Api(tags = "场景模块")
@RestController
@RequestMapping("/vrone/backend/scenes")
public class SceneController extends BaseController {

    private final ISceneService sceneService;

    public SceneController(@Qualifier("sceneServiceImplement") ISceneService sceneService) {
        this.sceneService = sceneService;
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @GetMapping("/list")
    @ApiOperation(value = "查询场景列表（管理端）", notes = "scene（场景实体，实体中包含查询条件）")
    public AjaxResult list(Scene scene) {
        List<Scene> list = sceneService.selectSceneList(scene);
        return success(list);
    }

    @Anonymous
    @GetMapping("/mySceneList/{userId}")
    @ApiOperation(value = "根据用户id查询场景列表", notes = "userId（用户id）")
    public AjaxResult getListByUser(@PathVariable("userId") Long userId) {
        List<Scene> list = sceneService.selectSceneListByUserId(userId);
        return success(list);
    }

    @Anonymous
    @GetMapping("/listByApp/{appId}")
    @ApiOperation(value = "根据展厅id查询场景列表", notes = "appId（展厅id）")
    public AjaxResult getListByApp(@PathVariable("appId") Long appId) {
        List<Scene> list = sceneService.selectSceneListByAppId(appId);
        return success(list);
    }

    @Anonymous
    @GetMapping(value = "/{sceneId}")
    @ApiOperation(value = "获取场景详细信息", notes = "传参为sceneId（场景id）")
    public AjaxResult getInfo(@PathVariable("sceneId") Long sceneId) {
        return success(sceneService.selectSceneById(sceneId));
    }

    @Anonymous
    @PostMapping
    @ApiOperation(value = "新增场景", notes = "传参为scene（场景实体）")
    public AjaxResult add(@RequestBody Scene scene) {
        if (!sceneService.insertScene(scene)) {
            return error("新增失败");
        }

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 201);
        ajaxResult.put("msg", "新增成功");
        return ajaxResult;
    }

    @Anonymous
    @PutMapping
    @ApiOperation(value = "修改场景", notes = "传参为scene（场景实体）")
    public AjaxResult edit(@RequestBody Scene scene) {
        if (!sceneService.updateScene(scene)) {
            return error("修改失败");
        }

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 201);
        ajaxResult.put("msg", "修改成功");
        return ajaxResult;
    }

}
