package com.ruoyi.project.controller;

import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.project.domain.DataSource;
import com.ruoyi.project.domain.Spot;
import com.ruoyi.project.domain.vo.SpotVo;
import com.ruoyi.project.service.ISpotService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 展示点Controller
 *
 * @author seeseele
 * @date 2024-05-09
 */

@Api(tags = "展示点模块")
@RestController
@RequestMapping("/vrone/backend/spots")
public class SpotController extends BaseController {

    private final ISpotService spotService;

    public SpotController(@Qualifier("spotServiceImplement") ISpotService spotService) {
        this.spotService = spotService;
    }

    @Anonymous
    @GetMapping("/list/{sceneId}")
    @ApiOperation(value = "根据用户场景查询展示点列表", notes = "传参为sceneId（场景id）")
    public AjaxResult getListBySceneId(@PathVariable("sceneId") Long sceneId) {

        List<SpotVo> list = spotService.selectSpotListBySceneId(sceneId);

        return success(list);
    }

    @Anonymous
    @PostMapping("/getDataSourceBySpot")
    @ApiOperation(value = "根据场景id和展示点id查询数据源", notes = "传参为sceneId（场景id），spotId（展示点id）")
    public AjaxResult getListBySceneId(@RequestBody JSONObject jsonObject) {
        Long sceneId = jsonObject.getLong("sceneId");
        Long spotId = jsonObject.getLong("spotId");

        String spotTitle = sceneId + "&" + spotId;

        DataSource dataSource = spotService.selectDataSourceBySpot(spotTitle);

        if (dataSource == null){
            return error("没有该数据源");
        }

        return success(dataSource);
    }

    @Anonymous
    @PatchMapping("/editSpot")
    @ApiOperation(value = "修改spot配置", notes = "传参为json")
    public AjaxResult edit(@RequestBody JSONObject jsonObject) {
        Spot spot = jsonObject.getObject("spot", Spot.class);
        Long sceneId = jsonObject.getLong("sceneId");

        if (!spotService.updateSpotBySceneId(sceneId, spot)){
            return error("修改失败");
        }

        return success("修改成功");
    }

    @Anonymous
    @PatchMapping("/mountSpot")
    @ApiOperation(value = "挂载数据源", notes = "传参为JSON， JSON中包含dataSourceId（数据源id）sceneId（场景id）spotId（展示点id）")
    public AjaxResult mountSpot(@RequestBody JSONObject jsonObject) {
        Long dataSourceId = jsonObject.getLong("dataSourceId");
        Long sceneId = jsonObject.getLong("sceneId");
        Long spotId = jsonObject.getLong("spotId");

        String spotTitle = sceneId + "&" + spotId;

        if (!spotService.mountSpot(dataSourceId, spotTitle)) {
            return error("挂载失败");
        }

        return success("挂载成功");
    }

    @Anonymous
    @PatchMapping("/unloadSpot")
    @ApiOperation(value = "卸载数据源", notes = "传参为JSON， JSON中包含dataSourceId（数据源id）sceneId（场景id）spotId（展示点id）")
    public AjaxResult unloadSpot(@RequestBody JSONObject jsonObject) {
        Long dataSourceId = jsonObject.getLong("dataSourceId");
        Long sceneId = jsonObject.getLong("sceneId");
        Long spotId = jsonObject.getLong("spotId");

        String spotTitle = sceneId + "&" + spotId;

        if (!spotService.unloadSpot(dataSourceId, spotTitle)) {
            return error("卸载失败");
        }

        return success("卸载成功");
    }

}
