package com.ruoyi.project.controller;

import java.util.List;

import com.ruoyi.common.annotation.Anonymous;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.project.domain.Template;
import com.ruoyi.project.service.ITemplateService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;

/**
 * 展厅模板Controller
 *
 * @author seeseele
 * @date 2024-05-09
 */
@Api(tags = "展厅模板模块")
@RestController
@RequestMapping("/vrone/backend/templates")
public class TemplateController extends BaseController {

    private final ITemplateService templateService;

    public TemplateController(@Qualifier("templateServiceImplement") ITemplateService templateService) {
        this.templateService = templateService;
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @GetMapping("/list")
    @ApiOperation(value = "查询展厅模板列表（管理端）", notes = "传参为template（展厅模板实体，实体中包含查询条件）")
    public AjaxResult list(Template template) {
        List<Template> list = templateService.selectTemplateList(template);

        return success(list);
    }

    @Anonymous
    @PostMapping("/showList")
    @ApiOperation(value = "查询展示的展厅模板列表", notes = "传参为template（展厅模板实体，实体中包含查询条件）")
    public AjaxResult showList(@RequestBody Template template) {
        List<Template> list = templateService.selectShowTemplateList(template);

        return success(list);
    }

    @Anonymous
    @GetMapping("/myTemplateList/{userId}")
    @ApiOperation(value = "查询用户已购买的模板列表", notes = "传参为userId（传参为userId（用户id）")
    public AjaxResult myTemplateList(@PathVariable("userId") Long userId) {
        List<Template> list = templateService.selectTemplateListByUserId(userId);

        return success(list);
    }

    @Anonymous
    @GetMapping("/{templateId}")
    @ApiOperation(value = "查询展厅模板详情", notes = "传参为templateId（展厅模板id）")
    public AjaxResult getInfo(@PathVariable("templateId") Long templateId) {

        Template template = templateService.selectTemplateById(templateId);

        if (template == null) {
            return error("没有查询到该数据");
        }
        // 浏览量加1
        template.setViewCount(template.getViewCount() + 1);
        templateService.updateTemplate(template);

        return success(template);
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @PostMapping()
    @ApiOperation(value = "新增展厅模板", notes = "传参为template（展厅模板实体）")
    public AjaxResult add(@RequestBody Template template) {
        if (!templateService.insertTemplate(template)) {
            return error("新增失败");
        }

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 201);
        ajaxResult.put("msg", "新增成功");
        return ajaxResult;
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @PutMapping()
    @ApiOperation(value = "修改展厅模板", notes = "传参为template（模板实体）")
    public AjaxResult edit(@RequestBody Template template) {
        if (!templateService.updateTemplate(template)) {
            return error("修改失败");
        }

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 201);
        ajaxResult.put("msg", "修改成功");
        return ajaxResult;
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @DeleteMapping("{templateId}")
    @ApiOperation(value = "删除展厅模板（管理端）", notes = "根据模板ID删除指定模板")
    public AjaxResult remove(@PathVariable Long templateId) {
        return toAjax(templateService.deleteTemplateById(templateId));
    }
}
