package com.ruoyi.project.controller;

import java.util.List;

import com.ruoyi.common.annotation.Anonymous;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.project.domain.TemplateLog;
import com.ruoyi.project.service.ITemplateLogService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;

/**
 * 购买模板记录Controller
 *
 * @author seeseele
 * @date 2024-05-13
 */
@Api(tags = "购买模板记录模块")
@RestController
@RequestMapping("/vrone/backend/templateLog")
public class TemplateLogController extends BaseController {

    private final ITemplateLogService templateLogService;

    public TemplateLogController(@Qualifier("templateLogServiceImplement") ITemplateLogService templateLogService) {
        this.templateLogService = templateLogService;
    }

    @Anonymous
    @GetMapping("/list")
    @ApiOperation(value = "查询购买模板记录列表", notes = "传参为templateLog（展厅模板实体，实体中包含查询条件）")
    public AjaxResult list(TemplateLog templateLog) {
        List<TemplateLog> list = templateLogService.selectTemplateLogList(templateLog);
        return success(list);
    }

    @Anonymous
    @GetMapping("/list/{userId}")
    @ApiOperation(value = "根据用户id查询购买模板记录列表", notes = "传参为userId（用户id）")
    public AjaxResult getListByUserId(@PathVariable("userId") Long userId) {
        List<TemplateLog> list = templateLogService.selectTemplateLogListByUserId(userId);
        return success(list);
    }

    @Anonymous
    @GetMapping(value = "/{templateLogId}")
    @ApiOperation(value = "获取购买模板记录详细信息", notes = "传参为templateLogId（购买模板记录id）")
    public AjaxResult getInfo(@PathVariable("templateLogId") Long templateLogId) {
        return success(templateLogService.selectTemplateLogById(templateLogId));
    }

    @Anonymous
    @PostMapping
    @ApiOperation(value = "新增购买模板记录", notes = "传参为templateLog（购买模板记录实体）")
    public AjaxResult add(@RequestBody TemplateLog templateLog) {
        if (!templateLogService.insertTemplateLog(templateLog)) {
            return error("新增失败");
        }

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 201);
        ajaxResult.put("msg", "新增成功");
        return ajaxResult;
    }

}
