package com.ruoyi.project.controller;

import java.util.List;

import com.ruoyi.common.annotation.Anonymous;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.project.domain.Transactions;
import com.ruoyi.project.service.ITransactionsService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 充值记录Controller
 *
 * @author seeseele
 * @date 2024-07-10
 */
@Api(tags = "充值记录模块")
@RestController
@RequestMapping("/vrone/backend/transactions")
public class TransactionsController extends BaseController {

    private final ITransactionsService transactionsService;

    public TransactionsController(@Qualifier("transactionsServiceImplement") ITransactionsService transactionsService){
        this.transactionsService = transactionsService;
    }

    @Anonymous
    @GetMapping("/list")
    @ApiOperation(value = "查询充值记录列表", notes = "传参为transactions（充值记录实体，实体中包含查询条件）")
    public TableDataInfo list(Transactions transactions) {
        startPage();
        List<Transactions> list = transactionsService.selectTransactionsList(transactions);
        return getDataTable(list);
    }

    @Anonymous
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取充值记录详细信息", notes = "传参为id（充值记录id，实体中包含查询条件）")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(transactionsService.selectTransactionsById(id));
    }

    @PostMapping
    @ApiOperation(value = "新增充值记录", notes = "传参为transactions（充值记录实体，实体中包含查询条件）")
    public AjaxResult add(@RequestBody Transactions transactions) {
        return toAjax(transactionsService.insertTransactions(transactions));
    }

    @PutMapping
    @ApiOperation(value = "修改充值记录", notes = "传参为transactions（充值记录实体，实体中包含查询条件）")
    public AjaxResult edit(@RequestBody Transactions transactions) {
        return toAjax(transactionsService.updateTransactions(transactions));
    }

}
