package com.ruoyi.project.controller;

import java.util.List;

import com.ruoyi.common.annotation.Anonymous;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.project.domain.sourceData.VideoData;
import com.ruoyi.project.service.IVideoDataService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;

/**
 * 视频数据Controller
 *
 * @author seeseele
 * @date 2024-05-09
 */
@Api(tags = "视频数据模块")
@RestController
@RequestMapping("/vrone/videoDatas")
public class VideoDataController extends BaseController {

    private final IVideoDataService videoDataService;

    public VideoDataController(@Qualifier("videoDataServiceImplement") IVideoDataService videoDataService) {
        this.videoDataService = videoDataService;
    }

    @Anonymous
    @GetMapping("/list")
    @ApiOperation(value = "查询视频数据列表", notes = "传参为videoData（视频数据实体，实体中包含查询条件）")
    public AjaxResult list(VideoData videoData) {
        List<VideoData> list = videoDataService.selectVideoDataList(videoData);

        return success(list);
    }

    @Anonymous
    @GetMapping(value = "/{videoId}")
    @ApiOperation(value = "获取视频数据详细信息", notes = "传参为videoId（视频数据id）")
    public AjaxResult getInfo(@PathVariable("videoId") Long videoId) {
        return success(videoDataService.selectVideoDataById(videoId));
    }

    @Anonymous
    @PostMapping
    @ApiOperation(value = "新增视频数据", notes = "传参为videoData（视频数据实体）")
    public AjaxResult add(@RequestBody VideoData videoData) {
        if (!videoDataService.insertVideoData(videoData)){
            return error("新增失败");
        }

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 201);
        ajaxResult.put("msg", "新增成功");
        return ajaxResult;
    }

    @Anonymous
    @PutMapping
    @ApiOperation(value = "修改视频数据", notes = "传参为videoData（视频数据实体）")
    public AjaxResult edit(@RequestBody VideoData videoData) {
        if (!videoDataService.updateVideoData(videoData)) {
            return error("修改失败");
        }

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 201);
        ajaxResult.put("msg", "修改成功");
        return ajaxResult;
    }

}
