package com.ruoyi.project.controller;

import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.project.service.IVirtualService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.web.bind.annotation.*;


@Api(tags = "获取详情模块")
@RestController
@RequestMapping("/vrone/backend/virtual")
public class VirtualController {

    private final IVirtualService virtualService;

    public VirtualController(@Qualifier("virtualServiceImplement") IVirtualService virtualService) {
        this.virtualService = virtualService;
    }

    @Anonymous
    @PostMapping("/info")
    @ApiOperation(value = "获取具体信息", notes = "传参为aid（场景id）sid（场景id）pid（点位id）")
    public AjaxResult getInfoList(@RequestBody JSONObject jsonObject) {

        AjaxResult ajaxResult = new AjaxResult();
        Long appId = jsonObject.getLong("aid");
        Long sceneId = jsonObject.getLong("sid");
        Long pointId = jsonObject.getLong("pid");

        //展厅信息
        ajaxResult.put("app", virtualService.getAppInfo(appId));
        //能够跳转的场景信息列表
        ajaxResult.put("sceneList", virtualService.getSceneVoList(appId));
        // 当前场景数据
        if (pointId.equals(0L)) {
            ajaxResult.put("currentSceneData", virtualService.getCurrentSceneDataByUnity(sceneId));
        } else {
            ajaxResult.put("currentSceneData", virtualService.getCurrentSceneDataByPanorama(sceneId));
        }

        return ajaxResult;
    }

    @Anonymous
    @GetMapping("/data")
    @ApiOperation(value = "720获取配置信息", notes = "sid（场景id）")
    public JSONObject getInfoList(@RequestParam("sid") String sceneIdStr) {
        Long sceneId = Long.parseLong(sceneIdStr);
        return virtualService.getSettingByPanorama(sceneId);
    }

}
