package com.ruoyi.project.controller;

import cn.dev33.satoken.stp.StpUtil;
import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.project.domain.VrUser;
import com.ruoyi.project.service.IVrUserService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * vr用户Controller
 *
 * @author seeseele
 * @date 2025-03-10
 */
@Api(tags = "vr用户模块")
@RestController
@RequestMapping("/vrone/backend/vrUser")
public class VrUserController extends BaseController {

    private final IVrUserService vrUserService;

    public VrUserController(
            @Qualifier("vrUserServiceImplement") IVrUserService vrUserService) {
        this.vrUserService = vrUserService;
    }

    @Anonymous
    @PostMapping("/register")
    @ApiOperation(value = "手机号密码注册接口", notes = "传参为jsonObject，其中包含vrUser（用户实体）")
    public AjaxResult register(
            @RequestBody JSONObject jsonObject) {
        VrUser vrUser = jsonObject.getObject("vrUser", VrUser.class);

        return vrUserService.register(vrUser);
    }

    @Anonymous
    @PostMapping("/login")
    @ApiOperation(value = "手机号密码登录接口", notes = "传参为jsonObject，其中包含phone（手机号），password（密码）")
    public AjaxResult login(
            @RequestBody JSONObject jsonObject) {
        String phone = jsonObject.getString("phone");
        String password = jsonObject.getString("password");

        VrUser vrUser = vrUserService.login(phone, password);

        AjaxResult result = new AjaxResult();
        if (vrUser == null) {
            result.put("code", 401); // 登录失败
            result.put("msg", "用户名或密码错误");
        } else {
            StpUtil.login(vrUser.getId());
            JSONObject data = new JSONObject();
            data.put("token", StpUtil.getTokenValue());
            data.put("user", vrUser);

            result.put("code", 200);
            result.put("data", data);
            result.put("msg", "登录成功");
        }

        return result;
    }

    @Anonymous
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取vr用户详细信息", notes = "")
    public AjaxResult getInfo(
            @PathVariable("id") Long id) {
        return success(vrUserService.selectVrUserById(id));
    }

    @Anonymous
    @PutMapping("/editPassword")
    @ApiOperation(value = "修改vr用户密码", notes = "传参为jsonObject，其中包含password（密码）")
    public AjaxResult editPassword(
            @RequestBody JSONObject jsonObject) {
        String newPassword = jsonObject.getString("password");
        long userId = StpUtil.getLoginIdAsLong();

        return toAjax(vrUserService.updateVrUserPassword(userId, newPassword));
    }

    @Anonymous
    @PutMapping("/editEmil")
    @ApiOperation(value = "修改vr用户邮箱", notes = "传参为jsonObject，其中包含email（邮箱）")
    public AjaxResult editEmil(
            @RequestBody JSONObject jsonObject) {
        String newEmail = jsonObject.getString("email");
        long userId = StpUtil.getLoginIdAsLong();

        return toAjax(vrUserService.updateVrUserEmail(userId, newEmail));
    }

    @Anonymous
    @PutMapping("/editAvatar")
    @ApiOperation(value = "修改vr用户头像", notes = "传参为jsonObject，其中包含avatar（头像url）")
    public AjaxResult editAvatar(
            @RequestBody JSONObject jsonObject) {
        String newAvatar = jsonObject.getString("avatar");
        long userId = StpUtil.getLoginIdAsLong();

        return toAjax(vrUserService.updateVrUserAvatar(userId, newAvatar));
    }

    @Anonymous
    @GetMapping("/isLogin")
    @ApiOperation(value = "查询登录状态接口")
    public AjaxResult isLogin() {
        return success("当前会话是否登录：" + StpUtil.isLogin());
    }

    @Anonymous
    @PostMapping("/logout")
    @ApiOperation(value = "注销登录接口")
    public AjaxResult logout() {
        StpUtil.logout();
        return success("注销登录成功");
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @GetMapping("/list")
    @ApiOperation(value = "查询vr用户列表", notes = "")
    public TableDataInfo list(VrUser vrUser) {
        startPage();
        List<VrUser> list = vrUserService.selectVrUserList(vrUser);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @PostMapping
    @ApiOperation(value = "新增vr用户", notes = "")
    public AjaxResult add(
            @RequestBody VrUser vrUser) {
        return toAjax(vrUserService.insertVrUser(vrUser));
    }

    @PreAuthorize("@ss.hasAnyRoles('admin,vrone_admin')")
    @PutMapping
    @ApiOperation(value = "修改vr用户", notes = "")
    public AjaxResult edit(
            @RequestBody VrUser vrUser) {
        return toAjax(vrUserService.updateVrUser(vrUser));
    }

}
