package com.ruoyi.project.mapper;

import java.util.List;

import com.ruoyi.project.domain.App;
import com.ruoyi.project.domain.vo.AppVo;
import org.apache.ibatis.annotations.Mapper;

/**
 * 展厅Mapper接口
 *
 * @author seeseele
 * @date 2024-05-09
 */
@Mapper
public interface AppMapper {

    /**
     * 查询展厅列表
     *
     * @param app 展厅
     * @return 展厅集合
     */
    List<App> selectAppList(App app);

    /**
     * 查询用于展示的展厅列表
     *
     * @param app 展厅
     * @return 展厅集合
     */
    List<App> selectShowAppList(App app);

    /**
     * 根据用户id查询展厅列表
     *
     * @param userId 用户id
     * @return 展厅
     */
    List<App> selectAppListByUserId(Long userId);

    /**
     * 查询展厅
     *
     * @param id 展厅主键
     * @return 展厅
     */
    App selectAppById(Long id);

    /**
     * 新增展厅
     *
     * @param app 展厅
     * @return 结果
     */
    int insertApp(App app);

    /**
     * 修改展厅
     *
     * @param app 展厅
     * @return 结果
     */
    int updateApp(App app);

    /**
     * 删除展厅
     *
     * @param id 展厅主键
     * @return 结果
     */
    int deleteAppById(Long id);

    /**
     * 批量删除展厅
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteAppByIds(Long[] ids);

}
