package com.ruoyi.project.mapper;

import java.util.List;

import com.ruoyi.project.domain.DataSource;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

/**
 * 数据源Mapper接口
 *
 * @author seeseele
 * @date 2024-05-09
 */
@Mapper
public interface DataSourceMapper {

    /**
     * 查询数据源
     *
     * @param id 数据源主键
     * @return 数据源
     */
    DataSource selectDataSourceById(Long id);

    /**
     * 根据展示点查询数据源
     *
     */
    DataSource selectDataSourceBySpot(@Param("spotTitle") String spotTitle);

    /**
     * 查询数据源列表
     *
     * @param dataSource 数据源
     * @return 数据源集合
     */
    List<DataSource> selectDataSourceList(DataSource dataSource);

    /**
     * 根据展厅id查询数据源列表
     *
     * @param appId 展厅id
     * @return 数据源集合
     */
    List<DataSource> selectDataSourceListByAppId(Long appId);

    /**
     * 新增数据源
     *
     * @param dataSource 数据源
     * @return 结果
     */
    int insertDataSource(DataSource dataSource);

    /**
     * 修改数据源
     *
     * @param dataSource 数据源
     * @return 结果
     */
    int updateDataSource(DataSource dataSource);

    /**
     * 修改数据源展示点
     */

    int updateSpot(@Param("dataSourceId") Long dataSourceId, @Param("spot") String spot);

    /**
     * 删除数据源
     *
     * @param id 数据源主键
     * @return 结果
     */
    int deleteDataSourceById(Long id);

    /**
     * 批量删除数据源
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteDataSourceByIds(Long[] ids);

}
