package com.ruoyi.project.mapper;

import java.util.List;

import com.ruoyi.project.domain.sourceData.ImageData;
import org.apache.ibatis.annotations.Mapper;

/**
 * 图片数据Mapper接口
 *
 * @author seeseele
 * @date 2024-05-09
 */
@Mapper
public interface ImageDataMapper {
    /**
     * 查询图片数据列表
     *
     * @param imageData 图片数据
     * @return 图片数据集合
     */
    List<ImageData> selectImageDataList(ImageData imageData);

    /**
     * 查询图片数据
     *
     * @param id 图片数据主键
     * @return 图片数据
     */
    ImageData selectImageDataById(Long id);

    /**
     * 根据数据源id查询视频数据
     *
     * @param dataSourceId 数据源主键
     * @return 视频数据
     */
    ImageData selectImageDataByDataSourceId(Long dataSourceId);

    /**
     * 新增图片数据
     *
     * @param imageData 图片数据
     * @return 结果
     */
    int insertImageData(ImageData imageData);

    /**
     * 修改图片数据
     *
     * @param imageData 图片数据
     * @return 结果
     */
    int updateImageData(ImageData imageData);

    /**
     * 删除图片数据
     *
     * @param id 图片数据主键
     * @return 结果
     */
    int deleteImageDataById(Long id);

    /**
     * 批量删除图片数据
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteImageDataByIds(Long[] ids);
}
