package com.ruoyi.project.mapper;

import com.ruoyi.project.domain.OrderDetails;
import com.ruoyi.project.domain.Orders;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

/**
 * 订单详情：此用于存储每个订单中包含的具体商品及其相关信息。Mapper接口
 *
 * @author seeseele
 * @date 2025-02-26
 */
@Mapper
public interface OrderDetailsMapper {

    /**
     * 查询订单详情：此用于存储每个订单中包含的具体商品及其相关信息。
     *
     * @param id 订单详情
     * @return 订单详情
     */
    OrderDetails selectOrderDetailsById(Long id);

    /**
     * 查询订单详情：此用于存储每个订单中包含的具体商品及其相关信息。列表
     *
     * @param orderDetails 订单详情
     * @return 订单详情
     */
    List<OrderDetails> selectOrderDetailsList(OrderDetails orderDetails);

    /**
     * 根据订单id查询订单详情
     *
     * @param orderId 订单id
     * @return 订单详情
     */
    List<OrderDetails> selectOrderDetailsByOrderId(Long orderId);

    /**
     * 新增订单详情：此用于存储每个订单中包含的具体商品及其相关信息。
     *
     * @param orderDetails 订单详情
     * @return 结果
     */
    int insertOrderDetails(OrderDetails orderDetails);

    /**
     * 批量插入数据
     */
    int insertOrderDetailsDataList(List<OrderDetails> dataList);

    /**
     * 修改订单详情：此用于存储每个订单中包含的具体商品及其相关信息。
     *
     * @param orderDetails 订单详情
     * @return 结果
     */
    int updateOrderDetails(OrderDetails orderDetails);

    /**
     * 删除订单详情：此用于存储每个订单中包含的具体商品及其相关信息。
     *
     * @param id 订单详情
     * @return 结果
     */
    int deleteOrderDetailsById(Long id);

    /**
     * 批量删除订单详情：此用于存储每个订单中包含的具体商品及其相关信息。
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteOrderDetailsByIds(Long[] ids);
}
