package com.ruoyi.project.mapper;

import java.util.List;
import com.ruoyi.project.domain.Scene;
import org.apache.ibatis.annotations.Mapper;

/**
 * 场景Mapper接口
 * 
 * @author seeseele
 * @date 2024-05-09
 */
@Mapper
public interface SceneMapper 
{
    /**
     * 查询场景
     * 
     * @param id 场景主键
     * @return 场景
     */
    Scene selectSceneById(Long id);

    /**
     * 查询场景列表
     * 
     * @param scene 场景
     * @return 场景集合
     */
    List<Scene> selectSceneList(Scene scene);

    /**
     * 查询场景列表
     *
     * @param userId 用户id
     * @return 场景集合
     */
    List<Scene> selectSceneListByUserId(Long userId);

    /**
     * 查询场景列表
     *
     * @param appId 展厅id
     * @return 场景集合
     */
    List<Scene> selectSceneListByAppId(Long appId);

    /**
     * 查询场景列表
     *
     * @param templateId 模板id
     * @return 场景集合
     */
    List<Scene> selectSceneListByTemplateId(Long templateId);

    /**
     * 新增场景
     * 
     * @param scene 场景
     * @return 结果
     */
    int insertScene(Scene scene);

    /**
     * 修改场景
     * 
     * @param scene 场景
     * @return 结果
     */
    int updateScene(Scene scene);

    /**
     * 删除场景
     * 
     * @param id 场景主键
     * @return 结果
     */
    int deleteSceneById(Long id);

    /**
     * 批量删除场景
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteSceneByIds(Long[] ids);
}
