package com.ruoyi.project.mapper;

import java.util.List;

import com.ruoyi.project.domain.sourceData.VideoData;
import org.apache.ibatis.annotations.Mapper;

/**
 * 视频数据Mapper接口
 *
 * @author seeseele
 * @date 2024-05-09
 */
@Mapper
public interface VideoDataMapper {
    /**
     * 查询视频数据列表
     *
     * @param videoData 视频数据
     * @return 视频数据集合
     */
    List<VideoData> selectVideoDataList(VideoData videoData);

    /**
     * 查询视频数据
     *
     * @param id 视频数据主键
     * @return 视频数据
     */
    VideoData selectVideoDataById(Long id);

    /**
     * 根据数据源id查询视频数据
     *
     * @param dataSourceId 数据源主键
     * @return 视频数据
     */
    VideoData selectVideoDataByDataSourceId(Long dataSourceId);

    /**
     * 新增视频数据
     *
     * @param videoData 视频数据
     * @return 结果
     */
    int insertVideoData(VideoData videoData);

    /**
     * 修改视频数据
     *
     * @param videoData 视频数据
     * @return 结果
     */
    int updateVideoData(VideoData videoData);

    /**
     * 删除视频数据
     *
     * @param id 视频数据主键
     * @return 结果
     */
    int deleteVideoDataById(Long id);

    /**
     * 批量删除视频数据
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteVideoDataByIds(Long[] ids);
}
