package com.ruoyi.project.mapper;

import com.ruoyi.project.domain.VrUser;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.math.BigDecimal;
import java.util.List;

/**
 * vr用户Mapper接口
 *
 * @author seeseele
 * @date 2025-03-10
 */
@Mapper
public interface VrUserMapper {

    /**
     * 查询vr用户列表
     *
     * @param vrUser vr用户
     * @return vr用户集合
     */
    List<VrUser> selectVrUserList(VrUser vrUser);

    /**
     * 查询vr用户列表
     *
     * @return vr用户集合
     */
    List<VrUser> selectUserOrderByMoney();

    /**
     * 查询vr用户列表
     *
     * @return vr用户集合
     */
    List<VrUser> selectUserByToday(String time);

    /**
     * 查询vr用户
     *
     * @param id vr用户主键
     * @return vr用户
     */
    VrUser selectVrUserById(Long id);

    /**
     * 根据用户名查询用户信息
     */
    VrUser selectVrUserByUserName(String userName);

    /**
     * 根据邮箱查询用户信息
     */
    VrUser selectVrUserByEmail(String email);

    /**
     * 根据手机号查询用户信息
     */
    VrUser selectVrUserByPhone(String phone);

    /**
     * 新增vr用户
     *
     * @param vrUser vr用户
     * @return 结果
     */
    int insertVrUser(VrUser vrUser);

    /**
     * 修改vr用户
     *
     * @param vrUser vr用户
     * @return 结果
     */
    int updateVrUser(VrUser vrUser);

    /**
     * 修改vr用户密码
     *
     * @return 结果
     */
    int updateVrUserPassword(@Param("userId") Long userId, @Param("newPassword") String newPassword);

    /**
     * 修改vr用户邮箱
     *
     * @return 结果
     */
    int updateVrUserEmail(@Param("userId") Long userId, @Param("newEmail") String newEmail);

    /**
     * 修改vr用户头像
     *
     * @return 结果
     */
    int updateVrUserAvatar(@Param("userId") Long userId, @Param("newAvatar") String newAvatar);

    /**
     * 修改vr用户
     *
     * @return 结果
     */
    int updateVrUserMoney(@Param("userId") Long userId, @Param("newTotalMoney") BigDecimal newTotalMoney, @Param("newMoney") BigDecimal newMoney);

    /**
     * 删除vr用户
     *
     * @param id vr用户主键
     * @return 结果
     */
    int deleteVrUserById(Long id);

    /**
     * 批量删除vr用户
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteVrUserByIds(Long[] ids);

}
