package com.ruoyi.project.service;

import java.util.List;

import com.ruoyi.project.domain.DataSource;
import com.ruoyi.project.domain.vo.DataSourceVo;

/**
 * 数据源Service接口
 *
 * @author seeseele
 * @date 2024-05-09
 */
public interface IDataSourceService {

    /**
     * 查询数据源列表
     *
     * @param dataSource 数据源
     * @return 数据源集合vo
     */
    List<DataSourceVo> selectDataSourceVoList(DataSource dataSource);

    /**
     * 根据展厅id查询数据源列表
     *
     * @param appId 展厅id
     * @return 数据源集合vo
     */
    List<DataSourceVo> selectDataSourceVoListByAppId(Long appId);

    /**
     * 查询数据源
     *
     * @param id 数据源主键
     * @return 数据源vo
     */
    DataSourceVo selectDataSourceVoById(Long id);

    /**
     * 新增图片类型的数据源
     *
     * @param dataSource 数据源
     * @param url        图片url
     * @param cover      图片缩略图url
     * @return 结果
     */
    boolean insertDataSourceByImageData(DataSource dataSource, String url, String cover);

    /**
     * 新增视频类型的数据源
     *
     * @param dataSource 数据源
     * @param url        视频url
     * @param cover      视频封面
     * @return 结果
     */
    boolean insertDataSourceByVideoData(DataSource dataSource, String url, String cover);

    /**
     * 新增超链接类型的数据源
     *
     * @param dataSource 数据源
     * @param data        data
     * @param cover      封面
     * @return 结果
     */
    boolean insertDataSourceByLinkData(DataSource dataSource, String data, String cover);

    /**
     * 新增图册类型的数据源
     *
     * @param dataSource 数据源
     * @param data        data
     * @param cover      封面
     * @return 结果
     */
    boolean insertDataSourceByAlbumData(DataSource dataSource, String data, String cover);

    /**
     * 新增模型类型的数据源
     *
     * @param dataSource 数据源
     * @param data        data
     * @param cover      封面
     * @return 结果
     */
    boolean insertDataSourceByModelData(DataSource dataSource, String data, String cover);

    /**
     * 修改数据源
     *
     * @param dataSource 数据源
     * @return 结果
     */
    boolean updateDataSource(DataSource dataSource);

    /**
     * 修改图片类型的数据源
     *
     * @param dataSource 数据源
     * @param data        图片data
     * @param cover      图片缩略图url
     * @return 结果
     */
    boolean updateDataSourceByImageData(DataSource dataSource, String data, String cover);

    /**
     * 修改视频类型的数据源
     *
     * @param dataSource 数据源
     * @param data        视频data
     * @param cover      视频封面
     * @return 结果
     */
    boolean updateDataSourceByVideoData(DataSource dataSource, String data, String cover);

    /**
     * 修改超链接类型的数据源
     *
     * @param dataSource 数据源
     * @param data        data
     * @param cover      封面
     * @return 结果
     */
    boolean updateDataSourceByLinkData(DataSource dataSource, String data, String cover);

    /**
     * 修改图册类型的数据源
     *
     * @param dataSource 数据源
     * @param data        data
     * @param cover      封面
     * @return 结果
     */
    boolean updateDataSourceByAlbumData(DataSource dataSource, String data, String cover);

    /**
     * 修改模型类型的数据源
     *
     * @param dataSource 数据源
     * @param data        data
     * @param cover      封面
     * @return 结果
     */
    boolean updateDataSourceByModelData(DataSource dataSource, String data, String cover);

    /**
     * 批量删除数据源
     *
     * @param ids 需要删除的数据源主键集合
     * @return 结果
     */
    boolean deleteDataSourceByIds(Long[] ids);

    /**
     * 删除数据源信息
     *
     * @param id 数据源主键
     * @return 结果
     */
    boolean deleteDataSourceById(Long id);
}
