package com.ruoyi.project.service.cache;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.ruoyi.common.constant.CacheConstants;
import com.ruoyi.project.domain.Cart;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

@Component
public class CartCacheService {

    //把 Java 对象转换成 JSON
    private final ObjectMapper objectMapper = new ObjectMapper();

    private final StringRedisTemplate redisTemplate;

    public CartCacheService(
            @Autowired StringRedisTemplate redisTemplate) {
        this.redisTemplate = redisTemplate;
    }

    /**
     * 获取订单vo缓存key
     *
     * @return 缓存id
     */
    public String getCacheKey(Long userId) {
        return CacheConstants.VRONE_MANAGE_CART_KEY + userId;
    }

    /**
     * 新增商品到购物车
     *
     * @param cart 购物车对象
     * @return 结果
     */
    public boolean addToCartToCart(Cart cart) throws JsonProcessingException {
        String key = getCacheKey(cart.getUserId());
        String cartJson = objectMapper.writeValueAsString(cart);
        redisTemplate.opsForHash().put(key, cart.getId().toString(), cartJson);
        return true;
    }

    /**
     * 获取购物车列表
     *
     * @param userId 用户id
     * @return 结果
     */
    public List<Cart> getCartToCache(Long userId) throws JsonProcessingException {
        String key = getCacheKey(userId);
        Map<Object, Object> entries = redisTemplate.opsForHash().entries(key);
        List<Cart> list = new ArrayList<>();
        for (Object entry : entries.values()) {
            list.add(objectMapper.readValue(entry.toString(), Cart.class));
        }
        return list;
    }

    /**
     * 删除购物车中的某个商品
     *
     * @param userId 用户id，模板id
     * @return 结果
     */
    public boolean deleteFromCartToCache(Long userId, Long id) {
        String key = getCacheKey(userId);
        redisTemplate.opsForHash().delete(key, String.valueOf(id));
        return true;
    }

    /**
     * 清空购物车
     *
     * @param userId 用户id
     * @return 结果
     */
    public boolean clearCartToCache(Long userId) {
        String key = getCacheKey(userId);
        redisTemplate.delete(key);
        return true;
    }
}
