package com.ruoyi.project.service.impl;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.project.domain.VrUser;
import com.ruoyi.project.domain.vo.AppVo;
import com.ruoyi.project.mapper.VrUserMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.mapper.AppMapper;
import com.ruoyi.project.domain.App;
import com.ruoyi.project.service.IAppService;

/**
 * 展厅Service业务层处理
 *
 * @author seeseele
 * @date 2024-05-09
 */
@Service("appServiceImplement")
public class AppServiceImpl implements IAppService {

    private final AppMapper appMapper;
    private final VrUserMapper userMapper;

    public AppServiceImpl(@Autowired AppMapper appMapper,
                          @Autowired VrUserMapper userMapper) {
        this.appMapper = appMapper;
        this.userMapper = userMapper;
    }

    public List<AppVo> translateToVoList(List<App> appList){
        HashMap<Long, VrUser> userHashMap = new HashMap<>();
        List<AppVo> appVoList = new ArrayList<>();

        for (App a : appList) {
            VrUser user;
            if (!userHashMap.containsKey(a.getUserId())) {
                user = userMapper.selectVrUserById(a.getUserId());
                userHashMap.put(a.getUserId(), user);
            } else {
                user = userHashMap.get(a.getUserId());
            }
            AppVo appVo = new AppVo(a, user);
            appVoList.add(appVo);
        }

        return appVoList;
    }

    /**
     * 查询展厅vo列表
     *
     * @param app 展厅
     * @return 展厅vo
     */
    @Override
    public List<AppVo> selectAppVoList(App app) {
        List<App> appList = appMapper.selectAppList(app);

        return translateToVoList(appList);
    }

    /**
     * 查询展厅vo列表
     *
     * @param app 展厅
     * @return 展厅vo
     */
    @Override
    public List<AppVo> selectShowAppVoList(App app) {
        List<App> appList = appMapper.selectShowAppList(app);
        System.out.println("输出展厅对象");
        System.out.println(appList);
        return translateToVoList(appList);
//        return true;
    }

    /**
     * 根据用户id查询展厅列表
     *
     * @param userId 用户id
     * @return 展厅
     */
    @Override
    public List<App> selectAppListByUserId(Long userId) {
        return appMapper.selectAppListByUserId(userId);
    }

    /**
     * 查询展厅vo
     *
     * @param id 展厅主键
     * @return 展厅vo
     */
    @Override
    public AppVo selectAppVoById(Long id) {
        App app = appMapper.selectAppById(id);
        VrUser user = userMapper.selectVrUserById(app.getUserId());

        return new AppVo(app, user);
    }

    /**
     * 新增展厅
     *
     * @param app 展厅
     * @return 结果
     */
    @Override
    public boolean insertApp(App app) {
        app.setCreateTime(DateUtils.getNowDate());
        return appMapper.insertApp(app) > 0;
    }

    /**
     * 修改展厅
     *
     * @param app 展厅
     * @return 结果
     */
    @Override
    public boolean updateApp(App app) {
        app.setUpdateTime(DateUtils.getNowDate());
        return appMapper.updateApp(app) > 0;
    }

    /**
     * 批量删除展厅
     *
     * @param ids 需要删除的展厅主键
     * @return 结果
     */
    @Override
    public boolean deleteAppByIds(Long[] ids) {
        return appMapper.deleteAppByIds(ids) > 0;
    }

    /**
     * 删除展厅信息
     *
     * @param id 展厅主键
     * @return 结果
     */
    @Override
    public boolean deleteAppById(Long id) {
        return appMapper.deleteAppById(id) > 0;
    }

}
