package com.ruoyi.project.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.mapper.ArticleMapper;
import com.ruoyi.project.domain.Article;
import com.ruoyi.project.service.IArticleService;

/**
 * 文章Service业务层处理
 * 
 * @author seeseele
 * @date 2024-06-09
 */
@Service("articleServiceImplement")
public class ArticleServiceImpl implements IArticleService {

    private final ArticleMapper articleMapper;

    public ArticleServiceImpl(@Autowired ArticleMapper articleMapper){
        this.articleMapper = articleMapper;
    }

    /**
     * 查询文章
     * 
     * @param id 文章主键
     * @return 文章
     */
    @Override
    public Article selectArticleById(Long id)
    {
        return articleMapper.selectArticleById(id);
    }

    /**
     * 查询文章列表
     * 
     * @param article 文章
     * @return 文章
     */
    @Override
    public List<Article> selectArticleList(Article article)
    {
        return articleMapper.selectArticleList(article);
    }

    /**
     * 新增文章
     * 
     * @param article 文章
     * @return 结果
     */
    @Override
    public boolean insertArticle(Article article)
    {
        article.setCreateTime(DateUtils.getNowDate());
        return articleMapper.insertArticle(article) > 0;
    }

    /**
     * 修改文章
     * 
     * @param article 文章
     * @return 结果
     */
    @Override
    public boolean updateArticle(Article article)
    {
        article.setUpdateTime(DateUtils.getNowDate());
        return articleMapper.updateArticle(article) > 0;
    }

    /**
     * 删除文章
     * @param id 文章id
     * @return
     */
    @Override
    public boolean deleteArticleById(Long id) {
        return articleMapper.deleteArticleById(id) > 0;
    }

}
