package com.ruoyi.project.service.impl;

import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.project.domain.VrUser;
import com.ruoyi.project.mapper.VrUserMapper;
import com.ruoyi.system.mapper.SysUserMapper;
import com.ruoyi.project.domain.Transactions;
import com.ruoyi.project.mapper.TransactionsMapper;
import com.ruoyi.project.service.IBalanceService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;

@Service("balanceServiceImplement")
public class BalanceServiceImpl implements IBalanceService {

    private final VrUserMapper userMapper;

    private final TransactionsMapper transactionsMapper;

    public BalanceServiceImpl(@Autowired VrUserMapper userMapper,
                              @Autowired TransactionsMapper transactionsMapper) {
        this.userMapper = userMapper;
        this.transactionsMapper = transactionsMapper;
    }

    /**
     * 用户充值
     *
     */
    @Override
    public AjaxResult recharge(Long userId, BigDecimal recharge, Integer paymentMethod) {
        VrUser user = userMapper.selectVrUserById(userId);

        BigDecimal totalMoney = user.getTotalMoney();
        BigDecimal money = user.getMoney();

        BigDecimal newTotalMoney = totalMoney.add(recharge);
        BigDecimal newMoney = money.add(recharge);

        if (userMapper.updateVrUserMoney(userId, newTotalMoney, newMoney) < 0) {
            return AjaxResult.error("用户充值失败");
        }

        Transactions transactions = new Transactions();
        transactions.setUserId(userId);
        transactions.setRecharge(recharge);
        transactions.setMoney(newMoney);
        transactions.setPaymentMethod(paymentMethod);
        transactions.setMark("用户充值");
        transactions.setPaymentType(0);
        transactions.setCreateTime(DateUtils.getNowDate());

        transactionsMapper.insertTransactions(transactions);

        return AjaxResult.success("充值成功");
    }
}
