package com.ruoyi.project.service.impl;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.ruoyi.project.domain.Cart;
import com.ruoyi.project.service.ICartService;
import com.ruoyi.project.service.cache.CartCacheService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service("cartServiceImplement")
public class CartServiceImpl implements ICartService {

    private final CartCacheService cartCacheService;

    public CartServiceImpl(
            @Autowired CartCacheService cartCacheService) {
        this.cartCacheService = cartCacheService;
    }

    /**
     * 新增商品到购物车
     *
     * @param cart 购物车对象
     * @return 结果
     */
    @Override
    public boolean addToCart(Cart cart) throws JsonProcessingException {
        return cartCacheService.addToCartToCart(cart);
    }

    /**
     * 获取购物车列表
     *
     * @param userId 用户id
     * @return 结果
     */
    @Override
    public List<Cart> getCart(Long userId) throws JsonProcessingException {
        return cartCacheService.getCartToCache(userId);
    }

    /**
     * 删除购物车中的某个商品
     *
     * @param userId 用户id，模板id
     * @return 结果
     */
    @Override
    public boolean deleteFromCart(Long userId, Long id) {
        return cartCacheService.deleteFromCartToCache(userId, id);
    }

    /**
     * 清空购物车
     *
     * @param userId 用户id
     * @return 结果
     */
    @Override
    public boolean clearCart(Long userId) {
        return cartCacheService.clearCartToCache(userId);
    }
}
