package com.ruoyi.project.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.mapper.DataTypeMapper;
import com.ruoyi.project.domain.DataType;
import com.ruoyi.project.service.IDataTypeService;

/**
 * 数据类型Service业务层处理
 * 
 * @author seeseele
 * @date 2024-05-09
 */
@Service("dataTypeServiceImplement")
public class DataTypeServiceImpl implements IDataTypeService 
{

    private final DataTypeMapper dataTypeMapper;

    public DataTypeServiceImpl(@Autowired DataTypeMapper dataTypeMapper){
        this.dataTypeMapper = dataTypeMapper;
    }

    /**
     * 查询数据类型
     * 
     * @param id 数据类型主键
     * @return 数据类型
     */
    @Override
    public DataType selectDataTypeById(Long id)
    {
        return dataTypeMapper.selectDataTypeById(id);
    }

    /**
     * 查询数据类型列表
     * 
     * @param dataType 数据类型
     * @return 数据类型
     */
    @Override
    public List<DataType> selectDataTypeList(DataType dataType)
    {
        return dataTypeMapper.selectDataTypeList(dataType);
    }

    /**
     * 新增数据类型
     * 
     * @param dataType 数据类型
     * @return 结果
     */
    @Override
    public boolean insertDataType(DataType dataType)
    {
        dataType.setCreateTime(DateUtils.getNowDate());
        return dataTypeMapper.insertDataType(dataType) > 0;
    }

    /**
     * 修改数据类型
     * 
     * @param dataType 数据类型
     * @return 结果
     */
    @Override
    public boolean updateDataType(DataType dataType)
    {
        dataType.setUpdateTime(DateUtils.getNowDate());
        return dataTypeMapper.updateDataType(dataType) > 0;
    }

    /**
     * 批量删除数据类型
     * 
     * @param ids 需要删除的数据类型主键
     * @return 结果
     */
    @Override
    public boolean deleteDataTypeByIds(Long[] ids)
    {
        return dataTypeMapper.deleteDataTypeByIds(ids) > 0;
    }

    /**
     * 删除数据类型信息
     * 
     * @param id 数据类型主键
     * @return 结果
     */
    @Override
    public boolean deleteDataTypeById(Long id)
    {
        return dataTypeMapper.deleteDataTypeById(id) > 0;
    }
}
