package com.ruoyi.project.service.impl;

import java.util.ArrayList;
import java.util.List;

import com.ruoyi.project.domain.Template;
import com.ruoyi.project.domain.vo.FavoritesVo;
import com.ruoyi.project.mapper.TemplateMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.mapper.FavoritesMapper;
import com.ruoyi.project.domain.Favorites;
import com.ruoyi.project.service.IFavoritesService;

/**
 * 收藏夹Service业务层处理
 *
 * @author seeseele
 * @date 2025-02-26
 */
@Service("favoritesServiceImplement")
public class FavoritesServiceImpl implements IFavoritesService {

    private final FavoritesMapper favoritesMapper;

    private final TemplateMapper templateMapper;

    public FavoritesServiceImpl(@Autowired FavoritesMapper favoritesMapper,
                                @Autowired TemplateMapper templateMapper) {
        this.favoritesMapper = favoritesMapper;
        this.templateMapper = templateMapper;
    }

    public FavoritesVo translateToVo(Favorites favorites){
        Template template = templateMapper.selectTemplateById(favorites.getTemplateId());
        return new FavoritesVo(favorites, template);
    }

    /**
     * 查询收藏夹
     *
     * @param id 收藏夹主键
     * @return 收藏夹
     */
    @Override
    public FavoritesVo selectFavoritesById(Long id) {
        return translateToVo(favoritesMapper.selectFavoritesById(id));
    }

    /**
     * 查询收藏夹列表
     *
     * @param favorites 收藏夹
     * @return 收藏夹
     */
    @Override
    public List<FavoritesVo> selectFavoritesList(Favorites favorites) {
        List<Favorites> favoritesLists = favoritesMapper.selectFavoritesList(favorites);
        List<FavoritesVo> favoritesVoList = new ArrayList<>();
        for (Favorites f : favoritesLists){
            favoritesVoList.add(translateToVo(f));
        }
        return favoritesVoList;
    }

    /**
     * 新增收藏夹
     *
     * @param favorites 收藏夹
     * @return 结果
     */
    @Override
    public boolean insertFavorites(Favorites favorites) {
        return favoritesMapper.insertFavorites(favorites) > 0;
    }

    /**
     * 修改收藏夹
     *
     * @param favorites 收藏夹
     * @return 结果
     */
    @Override
    public boolean updateFavorites(Favorites favorites) {
        return favoritesMapper.updateFavorites(favorites) > 0;
    }

    /**
     * 批量删除收藏夹
     *
     * @param ids 需要删除的收藏夹主键
     * @return 结果
     */
    @Override
    public boolean deleteFavoritesByIds(Long[] ids) {
        return favoritesMapper.deleteFavoritesByIds(ids) > 0;
    }

    /**
     * 删除收藏夹信息
     *
     * @param id 收藏夹主键
     * @return 结果
     */
    @Override
    public boolean deleteFavoritesById(Long id) {
        return favoritesMapper.deleteFavoritesById(id) > 0;
    }
}
