package com.ruoyi.project.service.impl;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.project.domain.App;
import com.ruoyi.project.domain.VrUser;
import com.ruoyi.project.domain.vo.AppVo;
import com.ruoyi.project.domain.vo.FeedbackVo;
import com.ruoyi.project.mapper.VrUserMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.mapper.FeedbackMapper;
import com.ruoyi.project.domain.Feedback;
import com.ruoyi.project.service.IFeedbackService;

/**
 * 用户反馈Service业务层处理
 *
 * @author seeseele
 * @date 2025-02-24
 */
@Service("feedbackServiceImplement")
public class FeedbackServiceImpl implements IFeedbackService {

    private final FeedbackMapper feedbackMapper;

    private final VrUserMapper userMapper;

    public FeedbackServiceImpl(@Autowired FeedbackMapper feedbackMapper,
                               @Autowired VrUserMapper userMapper) {
        this.feedbackMapper = feedbackMapper;
        this.userMapper = userMapper;
    }

    public List<FeedbackVo> translateToVoList(List<Feedback> feedbackList){
        HashMap<Long, VrUser> userHashMap = new HashMap<>();
        List<FeedbackVo> feedbackVoList = new ArrayList<>();

        for (Feedback f : feedbackList) {
            VrUser user;
            if (!userHashMap.containsKey(f.getUserId())) {
                user = userMapper.selectVrUserById(f.getUserId());
                userHashMap.put(f.getUserId(), user);
            } else {
                user = userHashMap.get(f.getUserId());
            }
            FeedbackVo feedbackVo = new FeedbackVo(f, user);
            feedbackVoList.add(feedbackVo);
        }

        return feedbackVoList;
    }

    /**
     * 查询用户反馈
     *
     * @param id 用户反馈主键
     * @return 用户反馈
     */
    @Override
    public Feedback selectFeedbackById(Long id) {
        return feedbackMapper.selectFeedbackById(id);
    }

    /**
     * 查询用户反馈列表
     *
     * @param feedback 用户反馈
     * @return 用户反馈
     */
    @Override
    public List<FeedbackVo> selectFeedbackList(Feedback feedback) {
        List<Feedback> feedbackList = feedbackMapper.selectFeedbackList(feedback);
        return translateToVoList(feedbackList);
    }

    /**
     * 新增用户反馈
     *
     * @param feedback 用户反馈
     * @return 结果
     */
    @Override
    public boolean insertFeedback(Feedback feedback) {
        feedback.setCreateTime(DateUtils.getNowDate());
        return feedbackMapper.insertFeedback(feedback) > 0;
    }

    /**
     * 修改用户反馈
     *
     * @param feedback 用户反馈
     * @return 结果
     */
    @Override
    public boolean updateFeedback(Feedback feedback) {
        feedback.setUpdateTime(DateUtils.getNowDate());
        return feedbackMapper.updateFeedback(feedback) > 0;
    }

    /**
     * 批量删除用户反馈
     *
     * @param ids 需要删除的用户反馈主键
     * @return 结果
     */
    @Override
    public boolean deleteFeedbackByIds(Long[] ids) {
        return feedbackMapper.deleteFeedbackByIds(ids) > 0;
    }

    /**
     * 删除用户反馈信息
     *
     * @param id 用户反馈主键
     * @return 结果
     */
    @Override
    public boolean deleteFeedbackById(Long id) {
        return feedbackMapper.deleteFeedbackById(id) > 0;
    }
}
