package com.ruoyi.project.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.mapper.FeedbackTypeMapper;
import com.ruoyi.project.domain.FeedbackType;
import com.ruoyi.project.service.IFeedbackTypeService;

/**
 * 用户反馈类型Service业务层处理
 *
 * @author seeseele
 * @date 2025-02-24
 */
@Service("feedbackTypeServiceImplement")
public class FeedbackTypeServiceImpl implements IFeedbackTypeService {

    private final FeedbackTypeMapper feedbackTypeMapper;

    public FeedbackTypeServiceImpl(@Autowired FeedbackTypeMapper feedbackTypeMapper) {
        this.feedbackTypeMapper = feedbackTypeMapper;
    }

    /**
     * 查询用户反馈类型
     *
     * @param id 用户反馈类型主键
     * @return 用户反馈类型
     */
    @Override
    public FeedbackType selectFeedbackTypeById(Long id) {
        return feedbackTypeMapper.selectFeedbackTypeById(id);
    }

    /**
     * 查询用户反馈类型列表
     *
     * @param feedbackType 用户反馈类型
     * @return 用户反馈类型
     */
    @Override
    public List<FeedbackType> selectFeedbackTypeList(FeedbackType feedbackType) {
        return feedbackTypeMapper.selectFeedbackTypeList(feedbackType);
    }

    /**
     * 新增用户反馈类型
     *
     * @param feedbackType 用户反馈类型
     * @return 结果
     */
    @Override
    public boolean insertFeedbackType(FeedbackType feedbackType) {
        feedbackType.setCreateTime(DateUtils.getNowDate());
        return feedbackTypeMapper.insertFeedbackType(feedbackType) > 0;
    }

    /**
     * 修改用户反馈类型
     *
     * @param feedbackType 用户反馈类型
     * @return 结果
     */
    @Override
    public boolean updateFeedbackType(FeedbackType feedbackType) {
        feedbackType.setUpdateTime(DateUtils.getNowDate());
        return feedbackTypeMapper.updateFeedbackType(feedbackType) > 0;
    }

    /**
     * 批量删除用户反馈类型
     *
     * @param ids 需要删除的用户反馈类型主键
     * @return 结果
     */
    @Override
    public boolean deleteFeedbackTypeByIds(Long[] ids) {
        return feedbackTypeMapper.deleteFeedbackTypeByIds(ids) > 0;
    }

    /**
     * 删除用户反馈类型信息
     *
     * @param id 用户反馈类型主键
     * @return 结果
     */
    @Override
    public boolean deleteFeedbackTypeById(Long id) {
        return feedbackTypeMapper.deleteFeedbackTypeById(id) > 0;
    }
}
