package com.ruoyi.project.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.mapper.ImageDataMapper;
import com.ruoyi.project.domain.sourceData.ImageData;
import com.ruoyi.project.service.IImageDataService;

/**
 * 图片数据Service业务层处理
 * 
 * @author seeseele
 * @date 2024-05-09
 */
@Service("imageDataServiceImplement")
public class ImageDataServiceImpl implements IImageDataService 
{

    private final ImageDataMapper imageDataMapper;

    public ImageDataServiceImpl(@Autowired ImageDataMapper imageDataMapper){
        this.imageDataMapper = imageDataMapper;
    }

    /**
     * 查询图片数据
     * 
     * @param id 图片数据主键
     * @return 图片数据
     */
    @Override
    public ImageData selectImageDataById(Long id)
    {
        return imageDataMapper.selectImageDataById(id);
    }

    /**
     * 查询图片数据列表
     * 
     * @param imageData 图片数据
     * @return 图片数据
     */
    @Override
    public List<ImageData> selectImageDataList(ImageData imageData)
    {
        return imageDataMapper.selectImageDataList(imageData);
    }

    /**
     * 新增图片数据
     * 
     * @param imageData 图片数据
     * @return 结果
     */
    @Override
    public boolean insertImageData(ImageData imageData)
    {
        imageData.setCreateTime(DateUtils.getNowDate());
        return imageDataMapper.insertImageData(imageData) > 0;
    }

    /**
     * 修改图片数据
     * 
     * @param imageData 图片数据
     * @return 结果
     */
    @Override
    public boolean updateImageData(ImageData imageData)
    {
        imageData.setCreateTime(DateUtils.getNowDate());
        return imageDataMapper.updateImageData(imageData) > 0;
    }

    /**
     * 批量删除图片数据
     * 
     * @param ids 需要删除的图片数据主键
     * @return 结果
     */
    @Override
    public boolean deleteImageDataByIds(Long[] ids)
    {
        return imageDataMapper.deleteImageDataByIds(ids) > 0;
    }

    /**
     * 删除图片数据信息
     * 
     * @param id 图片数据主键
     * @return 结果
     */
    @Override
    public boolean deleteImageDataById(Long id)
    {
        return imageDataMapper.deleteImageDataById(id) > 0;
    }
}
