package com.ruoyi.project.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.mapper.NoticeLogMapper;
import com.ruoyi.project.domain.NoticeLog;
import com.ruoyi.project.service.INoticeLogService;

/**
 * 通知记录Service业务层处理
 *
 * @author seeseele
 * @date 2025-02-24
 */
@Service("noticeLogServiceImplement")
public class NoticeLogServiceImpl implements INoticeLogService {

    private final NoticeLogMapper noticeLogMapper;

    public NoticeLogServiceImpl(@Autowired NoticeLogMapper noticeLogMapper) {
        this.noticeLogMapper = noticeLogMapper;
    }

    /**
     * 查询通知记录
     *
     * @param id 通知记录主键
     * @return 通知记录
     */
    @Override
    public NoticeLog selectNoticeLogById(Long id) {
        return noticeLogMapper.selectNoticeLogById(id);
    }

    /**
     * 查询通知记录列表
     *
     * @param noticeLog 通知记录
     * @return 通知记录
     */
    @Override
    public List<NoticeLog> selectNoticeLogList(NoticeLog noticeLog) {
        return noticeLogMapper.selectNoticeLogList(noticeLog);
    }

    /**
     * 新增通知记录
     *
     * @param noticeLog 通知记录
     * @return 结果
     */
    @Override
    public boolean insertNoticeLog(NoticeLog noticeLog) {
        noticeLog.setCreateTime(DateUtils.getNowDate());
        return noticeLogMapper.insertNoticeLog(noticeLog) > 0;
    }

    /**
     * 修改通知记录
     *
     * @param noticeLog 通知记录
     * @return 结果
     */
    @Override
    public boolean updateNoticeLog(NoticeLog noticeLog) {
        noticeLog.setUpdateTime(DateUtils.getNowDate());
        return noticeLogMapper.updateNoticeLog(noticeLog) > 0;
    }

    /**
     * 批量删除通知记录
     *
     * @param ids 需要删除的通知记录主键
     * @return 结果
     */
    @Override
    public boolean deleteNoticeLogByIds(Long[] ids) {
        return noticeLogMapper.deleteNoticeLogByIds(ids) > 0;
    }

    /**
     * 删除通知记录信息
     *
     * @param id 通知记录主键
     * @return 结果
     */
    @Override
    public boolean deleteNoticeLogById(Long id) {
        return noticeLogMapper.deleteNoticeLogById(id) > 0;
    }
}
