package com.ruoyi.project.service.impl;

import java.util.ArrayList;
import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.project.domain.NoticeLog;
import com.ruoyi.project.domain.vo.NoticeVo;
import com.ruoyi.project.mapper.NoticeLogMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.mapper.NoticeMapper;
import com.ruoyi.project.domain.Notice;
import com.ruoyi.project.service.INoticeService;

/**
 * 通知Service业务层处理
 *
 * @author seeseele
 * @date 2024-06-09
 */
@Service("noticeServiceImplement")
public class NoticeServiceImpl implements INoticeService {

    private final NoticeMapper noticeMapper;

    private final NoticeLogMapper noticeLogMapper;

    public NoticeServiceImpl(@Autowired NoticeMapper noticeMapper,
                             @Autowired NoticeLogMapper noticeLogMapper) {
        this.noticeMapper = noticeMapper;
        this.noticeLogMapper = noticeLogMapper;
    }

    /**
     * 查询通知列表
     *
     * @param notice 通知
     * @return 通知
     */
    @Override
    public List<Notice> selectNoticeList(Notice notice) {
        return noticeMapper.selectNoticeList(notice);
    }

    /**
     * 根据用户id查询通知列表
     *
     * @param userId 用户id
     * @return 通知集合
     */
    @Override
    public List<NoticeVo> selectNoticeListByUserId(Long userId) {
        List<NoticeLog> noticeLogs = noticeLogMapper.selectNoticeLogListByUserId(userId);
        List<NoticeVo> noticeList = new ArrayList<>();
        for(NoticeLog noticeLog : noticeLogs){
            Notice notice = noticeMapper.selectNoticeById(noticeLog.getNoticeId());
            if(notice != null){
                noticeList.add(new NoticeVo(notice, noticeLog.getState()));
            }
        }
        return noticeList;
    }

    /**
     * 查询通知
     *
     * @param id 通知主键
     * @return 通知
     */
    @Override
    public Notice selectNoticeById(Long id) {
        return noticeMapper.selectNoticeById(id);
    }

    /**
     * 新增通知
     *
     * @param notice 通知
     * @return 结果
     */
    @Override
    public boolean insertNotice(Notice notice) {
        notice.setCreateTime(DateUtils.getNowDate());
        return noticeMapper.insertNotice(notice) > 0;
    }

    /**
     * 新增通知
     *
     * @param notice 通知
     * @return 结果
     */
    @Override
    public boolean insertNoticeToAllUser(Notice notice) {
        notice.setCreateTime(DateUtils.getNowDate());
        if (noticeMapper.insertNotice(notice) < 1){
            return false;
        }

        NoticeLog noticeLog = new NoticeLog();
        noticeLog.setNoticeId(notice.getId());
        noticeLog.setUserId(0L);
        noticeLog.setState(2);
        noticeLog.setCreateTime(DateUtils.getNowDate());

        return noticeLogMapper.insertNoticeLog(noticeLog) > 0;
    }

    /**
     * 修改通知
     *
     * @param notice 通知
     * @return 结果
     */
    @Override
    public boolean updateNotice(Notice notice) {
        notice.setUpdateTime(DateUtils.getNowDate());
        return noticeMapper.updateNotice(notice) > 0;
    }

    /**
     * 删除通知
     * @param id 通知id
     * @return
     */
    @Override
    public boolean deleteNotice(Long id) {
        return noticeMapper.deleteNotice(id);
    }

}
