package com.ruoyi.project.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.mapper.NoticeTypeMapper;
import com.ruoyi.project.domain.NoticeType;
import com.ruoyi.project.service.INoticeTypeService;

/**
 * 通知类型Service业务层处理
 *
 * @author seeseele
 * @date 2025-02-24
 */
@Service("noticeTypeServiceImplement")
public class NoticeTypeServiceImpl implements INoticeTypeService {

    private final NoticeTypeMapper noticeTypeMapper;

    public NoticeTypeServiceImpl(@Autowired NoticeTypeMapper noticeTypeMapper) {
        this.noticeTypeMapper = noticeTypeMapper;
    }

    /**
     * 查询通知类型
     *
     * @param id 通知类型主键
     * @return 通知类型
     */
    @Override
    public NoticeType selectNoticeTypeById(Long id) {
        return noticeTypeMapper.selectNoticeTypeById(id);
    }

    /**
     * 查询通知类型列表
     *
     * @param noticeType 通知类型
     * @return 通知类型
     */
    @Override
    public List<NoticeType> selectNoticeTypeList(NoticeType noticeType) {
        return noticeTypeMapper.selectNoticeTypeList(noticeType);
    }

    /**
     * 新增通知类型
     *
     * @param noticeType 通知类型
     * @return 结果
     */
    @Override
    public boolean insertNoticeType(NoticeType noticeType) {
        noticeType.setCreateTime(DateUtils.getNowDate());
        return noticeTypeMapper.insertNoticeType(noticeType) > 0;
    }

    /**
     * 修改通知类型
     *
     * @param noticeType 通知类型
     * @return 结果
     */
    @Override
    public boolean updateNoticeType(NoticeType noticeType) {
        noticeType.setUpdateTime(DateUtils.getNowDate());
        return noticeTypeMapper.updateNoticeType(noticeType) > 0;
    }

    /**
     * 批量删除通知类型
     *
     * @param ids 需要删除的通知类型主键
     * @return 结果
     */
    @Override
    public boolean deleteNoticeTypeByIds(Long[] ids) {
        return noticeTypeMapper.deleteNoticeTypeByIds(ids) > 0;
    }

    /**
     * 删除通知类型信息
     *
     * @param id 通知类型主键
     * @return 结果
     */
    @Override
    public boolean deleteNoticeTypeById(Long id) {
        return noticeTypeMapper.deleteNoticeTypeById(id) > 0;
    }
}
