package com.ruoyi.project.service.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.mapper.OrderDetailsMapper;
import com.ruoyi.project.domain.OrderDetails;
import com.ruoyi.project.service.IOrderDetailsService;

/**
 * 订单详情Service业务层处理
 *
 * @author seeseele
 * @date 2025-02-26
 */
@Service("orderDetailsServiceImplement")
public class OrderDetailsServiceImpl implements IOrderDetailsService {

    private final OrderDetailsMapper orderDetailsMapper;

    public OrderDetailsServiceImpl(@Autowired OrderDetailsMapper orderDetailsMapper) {
        this.orderDetailsMapper = orderDetailsMapper;
    }

    /**
     * 查询订单详情
     *
     * @param id 订单详情主键
     * @return 订单详情
     */
    @Override
    public OrderDetails selectOrderDetailsById(Long id) {
        return orderDetailsMapper.selectOrderDetailsById(id);
    }

    /**
     * 查询订单详情列表
     *
     * @param orderDetails 订单详情
     * @return 订单详情
     */
    @Override
    public List<OrderDetails> selectOrderDetailsList(OrderDetails orderDetails) {
        return orderDetailsMapper.selectOrderDetailsList(orderDetails);
    }

    /**
     * 新增订单详情
     *
     * @param orderDetails 订单详情
     * @return 结果
     */
    @Override
    public boolean insertOrderDetails(OrderDetails orderDetails) {
        return orderDetailsMapper.insertOrderDetails(orderDetails) > 0;
    }

    /**
     * 修改订单详情
     *
     * @param orderDetails 订单详情
     * @return 结果
     */
    @Override
    public boolean updateOrderDetails(OrderDetails orderDetails) {
        return orderDetailsMapper.updateOrderDetails(orderDetails) > 0;
    }

    /**
     * 批量删除订单详情
     *
     * @param ids 需要删除的订单详情主键
     * @return 结果
     */
    @Override
    public boolean deleteOrderDetailsByIds(Long[] ids) {
        return orderDetailsMapper.deleteOrderDetailsByIds(ids) > 0;
    }

    /**
     * 删除订单详情信息
     *
     * @param id 订单详情主键
     * @return 结果
     */
    @Override
    public boolean deleteOrderDetailsById(Long id) {
        return orderDetailsMapper.deleteOrderDetailsById(id) > 0;
    }
}
