package com.ruoyi.project.service.impl;

import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.CommonUtils;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.project.domain.Scene;
import com.ruoyi.project.domain.Template;
import com.ruoyi.project.mapper.SceneMapper;
import com.ruoyi.project.mapper.TemplateMapper;
import com.ruoyi.project.service.ISceneService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 场景Service业务层处理
 *
 * @author seeseele
 * @date 2024-05-09
 */
@Service("sceneServiceImplement")
public class SceneServiceImpl implements ISceneService {

    private final SceneMapper sceneMapper;

    private final TemplateMapper templateMapper;


    public SceneServiceImpl(
            @Autowired SceneMapper sceneMapper,
            @Autowired TemplateMapper templateMapper) {
        this.sceneMapper = sceneMapper;
        this.templateMapper = templateMapper;
    }

    /**
     * 查询场景
     *
     * @param id 场景主键
     * @return 场景
     */
    @Override
    public Scene selectSceneById(Long id) {
        return sceneMapper.selectSceneById(id);
    }

    /**
     * 查询场景列表
     *
     * @param scene 场景
     * @return 场景
     */
    @Override
    public List<Scene> selectSceneList(Scene scene) {
        return sceneMapper.selectSceneList(scene);
    }

    /**
     * 查询场景列表
     *
     * @param userId 用户id
     * @return 场景集合
     */
    @Override
    public List<Scene> selectSceneListByUserId(Long userId) {
        return sceneMapper.selectSceneListByUserId(userId);
    }

    /**
     * 查询场景列表
     *
     * @param appId 展厅id
     * @return 场景集合
     */
    @Override
    public List<Scene> selectSceneListByAppId(Long appId) {
        return sceneMapper.selectSceneListByAppId(appId);
    }

    /**
     * 新增场景
     *
     * @param scene 场景
     * @return 结果
     */
    @Override
    public boolean insertScene(Scene scene) {
        Template template = templateMapper.selectTemplateById(scene.getTemplateId());

        // 获取配置文件
        String url = template.getUrl() + "/setting.json";
        JSONObject spotJson = CommonUtils.getContentByUrl(url, JSONObject.class);

        // 创建 spot 文件
        AjaxResult createSpotFile = CommonUtils.createSpotFile(spotJson);
        if (!createSpotFile.isSuccess()) {
            return false;
        }

        // 设置场景的 spot 字段
        scene.setSpot(createSpotFile.get("data").toString());
        scene.setType(template.getType());
        scene.setCreateTime(DateUtils.getNowDate());
        return sceneMapper.insertScene(scene) > 0;
    }


    /**
     * 修改场景
     *
     * @param scene 场景
     * @return 结果
     */
    @Override
    public boolean updateScene(Scene scene) {
        scene.setUpdateTime(DateUtils.getNowDate());
        return sceneMapper.updateScene(scene) > 0;
    }

    /**
     * 批量删除场景
     *
     * @param ids 需要删除的场景主键
     * @return 结果
     */
    @Override
    public boolean deleteSceneByIds(Long[] ids) {
        return sceneMapper.deleteSceneByIds(ids) > 0;
    }

    /**
     * 删除场景信息
     *
     * @param id 场景主键
     * @return 结果
     */
    @Override
    public boolean deleteSceneById(Long id) {
        return sceneMapper.deleteSceneById(id) > 0;
    }
}
