package com.ruoyi.project.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.mapper.TemplateLogMapper;
import com.ruoyi.project.domain.TemplateLog;
import com.ruoyi.project.service.ITemplateLogService;

/**
 * 购买模板记录Service业务层处理
 *
 * @author seeseele
 * @date 2024-05-13
 */
@Service("templateLogServiceImplement")
public class TemplateLogServiceImpl implements ITemplateLogService {

    private final TemplateLogMapper templateLogMapper;

    public TemplateLogServiceImpl(@Autowired TemplateLogMapper templateLogMapper) {
        this.templateLogMapper = templateLogMapper;
    }

    /**
     * 查询购买模板记录
     *
     * @param id 购买模板记录主键
     * @return 购买模板记录
     */
    @Override
    public TemplateLog selectTemplateLogById(Long id) {
        return templateLogMapper.selectTemplateLogById(id);
    }

    /**
     * 查询购买模板记录列表
     *
     * @param templateLog 购买模板记录
     * @return 购买模板记录
     */
    @Override
    public List<TemplateLog> selectTemplateLogList(TemplateLog templateLog) {
        return templateLogMapper.selectTemplateLogList(templateLog);
    }

    /**
     * 根据用户id查询购买模板记录列表
     *
     * @param userId 用户主键
     * @return 购买模板记录
     */
    @Override
    public List<TemplateLog> selectTemplateLogListByUserId(Long userId) {
        return templateLogMapper.selectTemplateLogListByUserId(userId);
    }

    /**
     * 新增购买模板记录
     *
     * @param templateLog 购买模板记录
     * @return 结果
     */
    @Override
    public boolean insertTemplateLog(TemplateLog templateLog) {
        templateLog.setCreateTime(DateUtils.getNowDate());
        return templateLogMapper.insertTemplateLog(templateLog) > 0;
    }

}
