package com.ruoyi.project.service.impl;

import java.util.ArrayList;
import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.project.domain.TemplateLog;
import com.ruoyi.project.mapper.TemplateLogMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.mapper.TemplateMapper;
import com.ruoyi.project.domain.Template;
import com.ruoyi.project.service.ITemplateService;

/**
 * 展厅模板Service业务层处理
 *
 * @author seeseele
 * @date 2024-05-09
 */
@Service("templateServiceImplement")
public class TemplateServiceImpl implements ITemplateService {

    private final TemplateMapper templateMapper;

    private final TemplateLogMapper templateLogMapper;

    public TemplateServiceImpl(@Autowired TemplateMapper templateMapper,
                               @Autowired TemplateLogMapper templateLogMapper) {
        this.templateMapper = templateMapper;
        this.templateLogMapper = templateLogMapper;
    }

    /**
     * 根据展厅模板id查询展厅模板
     *
     * @param id 展厅模板主键
     * @return 展厅模板
     */
    @Override
    public Template selectTemplateById(Long id) {
        return templateMapper.selectTemplateById(id);
    }

    /**
     * 查询展厅模板列表
     *
     * @param template 展厅模板
     * @return 展厅模板
     */
    @Override
    public List<Template> selectTemplateList(Template template) {
        return templateMapper.selectTemplateList(template);
    }

    /**
     * 查询展示的展厅模板列表
     *
     * @param template 展厅模板
     * @return 展厅模板
     */
    @Override
    public List<Template> selectShowTemplateList(Template template) {
        return templateMapper.selectShowTemplateList(template);
    }

    /**
     * 根据用户id查询模板列表
     *
     * @param userId 用户主键
     * @return 购买模板
     */
    @Override
    public List<Template> selectTemplateListByUserId(Long userId) {
        List<TemplateLog> templateLogList = templateLogMapper.selectTemplateLogListByUserId(userId);
        List<Template> templateList = new ArrayList<>();

        for (TemplateLog templateLog : templateLogList) {
            Template template = templateMapper.selectTemplateById(templateLog.getTemplateId());
            templateList.add(template);
        }

        return templateList;
    }


    /**
     * 新增展厅模板
     *
     * @param template 展厅模板
     * @return 结果
     */
    @Override
    public boolean insertTemplate(Template template) {
        template.setUserId(SecurityUtils.getLoginUser().getUserId());
        template.setCreateTime(DateUtils.getNowDate());
        return templateMapper.insertTemplate(template) > 0;
    }

    /**
     * 修改展厅模板
     *
     * @param template 展厅模板
     * @return 结果
     */
    @Override
    public boolean updateTemplate(Template template) {
        template.setUpdateTime(DateUtils.getNowDate());
        return templateMapper.updateTemplate(template) > 0;
    }


    /**
     * 删除模板信息
     *
     * @param id 模板主键
     * @return 结果
     */
    @Override
    public boolean deleteTemplateById(Long id) {
        return templateMapper.deleteTemplateById(id) > 0;
    }

}
