package com.ruoyi.project.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.mapper.TransactionsMapper;
import com.ruoyi.project.domain.Transactions;
import com.ruoyi.project.service.ITransactionsService;

/**
 * 充值记录Service业务层处理
 *
 * @author seeseele
 * @date 2024-07-10
 */
@Service("transactionsServiceImplement")
public class TransactionsServiceImpl implements ITransactionsService {

    private final TransactionsMapper transactionsMapper;

    public TransactionsServiceImpl(@Autowired TransactionsMapper transactionsMapper) {
        this.transactionsMapper = transactionsMapper;
    }

    /**
     * 查询充值记录
     *
     * @param id 充值记录主键
     * @return 充值记录
     */
    @Override
    public Transactions selectTransactionsById(Long id) {
        return transactionsMapper.selectTransactionsById(id);
    }

    /**
     * 查询充值记录列表
     *
     * @param transactions 充值记录
     * @return 充值记录
     */
    @Override
    public List<Transactions> selectTransactionsList(Transactions transactions) {
        return transactionsMapper.selectTransactionsList(transactions);
    }

    /**
     * 新增充值记录
     *
     * @param transactions 充值记录
     * @return 结果
     */
    @Override
    public boolean insertTransactions(Transactions transactions) {
        transactions.setCreateTime(DateUtils.getNowDate());
        return transactionsMapper.insertTransactions(transactions) > 0;
    }

    /**
     * 修改充值记录
     *
     * @param transactions 充值记录
     * @return 结果
     */
    @Override
    public boolean updateTransactions(Transactions transactions) {
        transactions.setUpdateTime(DateUtils.getNowDate());
        return transactionsMapper.updateTransactions(transactions) > 0;
    }

}
