package com.ruoyi.project.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.mapper.VideoDataMapper;
import com.ruoyi.project.domain.sourceData.VideoData;
import com.ruoyi.project.service.IVideoDataService;

/**
 * 视频数据Service业务层处理
 * 
 * @author seeseele
 * @date 2024-05-09
 */
@Service("videoDataServiceImplement")
public class VideoDataServiceImpl implements IVideoDataService
{

    private final VideoDataMapper videoDataMapper;

    public VideoDataServiceImpl(@Autowired VideoDataMapper videoDataMapper){
        this.videoDataMapper = videoDataMapper;
    }

    /**
     * 查询视频数据
     * 
     * @param id 视频数据主键
     * @return 视频数据
     */
    @Override
    public VideoData selectVideoDataById(Long id)
    {
        return videoDataMapper.selectVideoDataById(id);
    }

    /**
     * 查询视频数据列表
     * 
     * @param videoData 视频数据
     * @return 视频数据
     */
    @Override
    public List<VideoData> selectVideoDataList(VideoData videoData)
    {
        return videoDataMapper.selectVideoDataList(videoData);
    }

    /**
     * 新增视频数据
     * 
     * @param videoData 视频数据
     * @return 结果
     */
    @Override
    public boolean insertVideoData(VideoData videoData)
    {
        return videoDataMapper.insertVideoData(videoData) > 0;
    }

    /**
     * 修改视频数据
     * 
     * @param videoData 视频数据
     * @return 结果
     */
    @Override
    public boolean updateVideoData(VideoData videoData)
    {
        return videoDataMapper.updateVideoData(videoData) > 0;
    }

    /**
     * 批量删除视频数据
     * 
     * @param ids 需要删除的视频数据主键
     * @return 结果
     */
    @Override
    public boolean deleteVideoDataByIds(Long[] ids)
    {
        return videoDataMapper.deleteVideoDataByIds(ids) > 0;
    }

    /**
     * 删除视频数据信息
     * 
     * @param id 视频数据主键
     * @return 结果
     */
    @Override
    public boolean deleteVideoDataById(Long id)
    {
        return videoDataMapper.deleteVideoDataById(id) > 0;
    }
}
