package com.ruoyi.project.service.impl;

import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.common.utils.CommonUtils;
import com.ruoyi.project.domain.*;
import com.ruoyi.project.domain.vo.DataSourceVo;
import com.ruoyi.project.domain.vo.PanoramaVo;
import com.ruoyi.project.domain.vo.SceneVo;
import com.ruoyi.project.domain.vo.UnityVo;
import com.ruoyi.project.mapper.*;
import com.ruoyi.project.service.IVirtualService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

@Service("virtualServiceImplement")
public class VirtualServiceImpl implements IVirtualService {

    private final AppMapper appMapper;

    private final TemplateMapper templateMapper;

    private final SceneMapper sceneMapper;

    private final DataSourceMapper dataSourceMapper;

    private final ImageDataMapper imageDataMapper;

    private final VideoDataMapper videoDataMapper;

    public VirtualServiceImpl(
            @Autowired AppMapper appMapper,
            @Autowired TemplateMapper templateMapper,
            @Autowired SceneMapper sceneMapper,
            @Autowired DataSourceMapper dataSourceMapper,
            @Autowired ImageDataMapper imageDataMapper,
            @Autowired VideoDataMapper videoDataMapper) {
        this.appMapper = appMapper;
        this.templateMapper = templateMapper;
        this.sceneMapper = sceneMapper;
        this.dataSourceMapper = dataSourceMapper;
        this.imageDataMapper = imageDataMapper;
        this.videoDataMapper = videoDataMapper;
    }

    /**
     * 获取app详情
     */
    @Override
    public JSONObject getAppInfo(Long appId) {
        App app = appMapper.selectAppById(appId);

        JSONObject jsonObject = new JSONObject();
        jsonObject.put("id", app.getId().toString());
        jsonObject.put("name", app.getTitle());
        jsonObject.put("intro", app.getIntroduction());
        jsonObject.put("cover", app.getCover());
        jsonObject.put("video", app.getVideo());
        return jsonObject;
    }

    /**
     * 获取展厅下sceneVoList
     */
    @Override
    public List<SceneVo> getSceneVoList(Long appId) {
        List<Scene> sceneList = sceneMapper.selectSceneListByAppId(appId);
        List<SceneVo> sceneVoList = new ArrayList<>();

        for (Scene scene : sceneList) {
            Template template = templateMapper.selectTemplateById(scene.getTemplateId());

            String url = template.getUrl();

            SceneVo sceneVo = new SceneVo();
            sceneVo.setId(scene.getId().toString());
            sceneVo.setType(scene.getType().toString());
            sceneVo.setName(scene.getTitle());
            sceneVo.setUrl(url);
            sceneVo.setCover(scene.getCover());
            sceneVoList.add(sceneVo);
        }

        return sceneVoList;
    }


    /**
     * 获取场景详情数据(unity)
     */
    @Override
    public JSONObject getCurrentSceneDataByUnity(Long sceneId) {
        Scene scene = sceneMapper.selectSceneById(sceneId);

        List<Spot> spotList = CommonUtils.translateToList(scene.getSpot(), "spots", Spot.class);
        HashMap<String, DataSourceVo> dataMap = CommonUtils.getDataSourceVoMap(scene, dataSourceMapper, imageDataMapper, videoDataMapper);
        List<UnityVo> unityVoList = new ArrayList<>();
        for (Spot s : spotList) {
            UnityVo unityVo = new UnityVo(s);

            String spotTitle = sceneId + "&" + s.getId();
            if (dataMap.containsKey(spotTitle)) {
                DataSourceVo d = dataMap.get(spotTitle);
                unityVo.setDataUrl(d.getUrl());
                unityVo.setCoverUrl(d.getCover());
            }
            unityVoList.add(unityVo);
        }

        JSONObject currentSceneData = new JSONObject();
        currentSceneData.put("id", sceneId.toString());
        currentSceneData.put("type", scene.getType().toString());
        currentSceneData.put("name", scene.getTitle());
        currentSceneData.put("spots", unityVoList);

        return currentSceneData;
    }

    /**
     *  获取场景配置文件（全景）
     */
    @Override
    public JSONObject getSettingByPanorama(Long sceneId){
        Scene scene = sceneMapper.selectSceneById(sceneId);
        String setting = scene.getSpot();

        List<Spot> spotList = CommonUtils.translateToList(setting, "spots", Spot.class);
        HashMap<String, DataSourceVo> dataMap = CommonUtils.getDataSourceVoMap(scene, dataSourceMapper,imageDataMapper, videoDataMapper);
        List<PanoramaVo> panoramaVoList = new ArrayList<>();
        for (Spot s : spotList) {
            PanoramaVo panoramaVo = new PanoramaVo(s);

            String spotTitle = sceneId + "&" + s.getId();
            if (dataMap.containsKey(spotTitle)) {
                DataSourceVo d = dataMap.get(spotTitle);
                panoramaVo.setUrl(d.getUrl());
            }
            panoramaVoList.add(panoramaVo);
        }

        List<Point> pointList = CommonUtils.translateToList(setting, "points", Point.class);

        JSONObject jsonObject = new JSONObject();
        jsonObject.put("points", pointList);
        jsonObject.put("spots", panoramaVoList);

        return jsonObject;
    }


    /**
     * 获取场景详情数据(全景)
     */
    @Override
    public JSONObject getCurrentSceneDataByPanorama(Long sceneId){
        Scene scene = sceneMapper.selectSceneById(sceneId);

        Template template = templateMapper.selectTemplateById(scene.getTemplateId());
        String url = template.getUrl() + "/template.json";

        JSONObject json = CommonUtils.getContentByUrl(url, JSONObject.class);

        JSONObject currentSceneData = new JSONObject();
        currentSceneData.put("id", sceneId.toString());
        currentSceneData.put("type", scene.getType().toString());
        currentSceneData.put("points", json.getJSONArray("points"));
        currentSceneData.put("spots", json.getJSONArray("spots"));

        return currentSceneData;
    }
}
