package com.ruoyi.controller;

import cn.dev33.satoken.annotation.SaCheckLogin;
import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.domain.MApp;
import com.ruoyi.domain.vo.MAppVo;
import com.ruoyi.service.MAppService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author xuanxuan
 * 展厅Controller
 */
@Api(tags = "展厅模块")
@RestController
@RequestMapping("/vrone/mobile/apps")
@Anonymous
public class MAppController extends BaseController {

    @Autowired
    private MAppService appService;


    @PostMapping("/showList")
    @ApiOperation(value = "查询用于展示的展厅列表", notes = "传参为app（展厅实体，实体中包含查询条件）")
    public AjaxResult showList(@RequestBody MApp app) {
        List<MAppVo> list = appService.selectShowAppVoList(app);
        return success(list);
    }

    @SaCheckLogin
    @PostMapping("/myAppList")
    @ApiOperation(value = "根据用户id查询展厅列表", notes = "传参为userId（用户id）")
    public AjaxResult getListByUserId(@RequestBody MApp app) {
        long userId = app.getUserId();
        System.out.println(userId);
        List<MApp> list = appService.selectAppListByUserId(userId);

        return success(list);
    }


    @PostMapping(value = "/details")
    @ApiOperation(value = "获取展厅详细信息", notes = "传参为appId（展厅id）")
    public AjaxResult getInfo(@RequestBody MApp app) {

        appService.incrementViewCount(app.getId());

        return success(appService.selectAppVoById(app.getId()));
    }

    @SaCheckLogin
    @PostMapping(value = "/add")
    @ApiOperation(value = "新增展厅", notes = "传参为app（展厅实体）")
    public AjaxResult add(@RequestBody MApp app) {
        if (!appService.insertApp(app)) {
            return error("新增失败");
        }

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 201);
        ajaxResult.put("msg", "新增成功");
        return ajaxResult;
    }

    @SaCheckLogin
    @PutMapping(value = "/edit")
    @ApiOperation(value = "修改展厅", notes = "传参为app（展厅实体）")
    public AjaxResult edit(@RequestBody MApp app) {
        if (!appService.updateApp(app)) {
            return error("修改失败");
        }

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 201);
        ajaxResult.put("msg", "修改成功");
        return ajaxResult;
    }
}
