package com.ruoyi.controller;

import cn.dev33.satoken.annotation.SaCheckLogin;
import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.common.config.RuoYiConfig;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.file.FileUploadUtils;
import com.ruoyi.common.utils.file.FileUtils;
import com.ruoyi.domain.MApp;
import com.ruoyi.domain.MFeedback;
import com.ruoyi.domain.vo.MAppVo;
import com.ruoyi.framework.config.ServerConfig;
import com.ruoyi.service.MAppService;
import com.ruoyi.service.MFeedbackService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.io.File;
import java.io.IOException;
import java.util.List;

/**
 * @author xuanxuan
 * 用户反馈Controller
 */
@Api(tags = "用户反馈模块")
@RestController
@RequestMapping("/vrone/mobile/feedback")
@Anonymous
@SaCheckLogin
public class MFeedbackController extends BaseController {

    @Autowired
    private ServerConfig serverConfig;

    @Autowired
    private MFeedbackService feedbackService;

    @PostMapping("/add")
    @ApiOperation(value = "用户新增反馈", notes = "传参为feedback（反馈内容，反馈文件）")
    public AjaxResult add(@RequestBody MFeedback feedback) throws IOException {

        return success(feedbackService.insertFeedback(feedback));
    }



    @PostMapping("/getFeedbackList")
    @ApiOperation(value = "根据用户id获取反馈列表", notes = "传参为feedback（用户id）")
    public AjaxResult getFeedbackList(@RequestBody MFeedback feedback){

        return success(feedbackService.selectMFeedbackByUserId(feedback.getUserId()));
    }

    @PostMapping("/getFeedbackDetail")
    @ApiOperation(value = "根据反馈id获取反馈详情", notes = "传参为id（反馈id）")
    public AjaxResult getFeedbackDetail(@RequestBody MFeedback feedback){

        return success(feedbackService.selectMFeedbackById(feedback.getId()));
    }


    /**
     * 通用上传请求（单个）
     */
    @PostMapping("/upload")
    public AjaxResult uploadFile(MultipartFile file) throws Exception
    {
        try
        {
            // 上传文件路径
            String filePath = RuoYiConfig.getUploadPath();
            // 上传并返回新文件名称
            String fileName = FileUploadUtils.upload(filePath, file);
            String url = serverConfig.getUrl() + fileName;
            AjaxResult ajax = AjaxResult.success();
            ajax.put("url", url);
            ajax.put("fileName", fileName);
            ajax.put("newFileName", FileUtils.getName(fileName));
            ajax.put("originalFilename", file.getOriginalFilename());
            return AjaxResult.success(ajax);
        }
        catch (Exception e)
        {
            return AjaxResult.error(e.getMessage());
        }
    }
}
