package com.ruoyi.controller;

import cn.dev33.satoken.annotation.SaCheckLogin;
import cn.dev33.satoken.stp.StpUtil;
import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.common.core.controller.BaseController;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.domain.MOrderDetails;
import com.ruoyi.domain.MOrders;
import com.ruoyi.domain.MTemplate;
import com.ruoyi.domain.vo.MOrdersVo;
import com.ruoyi.service.MOrdersService;
import com.ruoyi.service.cache.MOrderCacheService;
import io.swagger.annotations.Api;

import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author xuanxuan
 * 订单Controller
 */
@Api(tags = "订单模块")
@RestController
@RequestMapping("/vrone/mobile/orders")
@Anonymous
@SaCheckLogin
public class MOrdersController extends BaseController {

    @Autowired
    private MOrdersService ordersService;

    @Autowired
    private MOrderCacheService orderCacheService;

    @Anonymous
    @PostMapping("/generate")
    @ApiOperation(value = "生成订单", notes = "传参为jsonObject，其中包含token，orders(订单)，detailList(订单详情列表)")
    public AjaxResult generate(
            @RequestBody JSONObject jsonObject) {
        // 获取订单信息
        MOrders orders = jsonObject.getObject("orders", MOrders.class);
        // 获取订单详情str
        String detailStr = jsonObject.getString("detailList");
        // 转化为订单详情列表
        List<MOrderDetails> detailList = JSON.parseArray(detailStr, MOrderDetails.class);

        // 通过sa-token获取用户id
        long userId = StpUtil.getLoginIdAsLong();
        if (userId != orders.getUserId()) {
            return error("生成订单用户和订单用户不同");
        }

        for (MOrderDetails orderDetails : detailList) {
            MTemplate template = ordersService.selectTemplateById(orderDetails.getTemplateId());
            if (template == null) {
                return error("模板不存在");
            }
            if (template.getStatus() != 1) {
                return error("模板状态异常");
            }
            if (template.getPrice().compareTo(orderDetails.getPrice()) != 0) {
                return error("订单价格异常");
            }
        }

        MOrdersVo orderVo = ordersService.createOrderVo(orders, detailList);

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 200);
        ajaxResult.put("msg", "生成订单成功");
        ajaxResult.put("data", orderVo);
        return ajaxResult;
    }

    @GetMapping("/listByUserId")
    @ApiOperation(value = "通过userId查询订单列表", notes = "携带token调用")
    public AjaxResult listByUserId() {
        // 通过sa-token获取用户id
        long userId = StpUtil.getLoginIdAsLong();
        System.out.println(userId);
        List<MOrdersVo> orderVoList = ordersService.selectOrderVoListByUserId(userId);

        return success(orderVoList);
    }


    @PostMapping("/getInfo")
    @ApiOperation(value = "获取订单详细信息", notes = "携带token调用,传参为id（订单id）")
    public AjaxResult getInfo(@RequestBody MOrders orders) {
        long userId = StpUtil.getLoginIdAsLong();

        //从缓存中获取订单
        MOrdersVo orderVo = ordersService.selectOrdersToCache(userId, orders.getId());

        if (orderVo == null) {
            return AjaxResult.error("订单不存在");
        }

        //向缓存中添加模板名称
        ordersService.fillTemplateNames(orderVo);

        return success(orderVo);
    }

    /**
     * 删除 Redis 缓存中的订单
     *
     * @return 操作结果
     */
    @DeleteMapping("/clearOrdersCache")
    @ApiOperation(value = "删除Redis缓存中的订单", notes = "传参为id（订单id）")
    public AjaxResult clearOrdersCache() {
          orderCacheService.clearOrdersCache();
        return AjaxResult.success("缓存清除成功");
    }

    @PutMapping("/payment")
    @ApiOperation(value = "支付订单", notes = "传参为jsonObject，其中包含token，订单")
    public AjaxResult payment(
            @RequestBody JSONObject jsonObject) {
        Long orderId = jsonObject.getLong("orderId");

        MOrdersVo orderVo = ordersService.selectOrdersToCache(StpUtil.getLoginIdAsLong(), orderId);
        if (orderVo == null) {
            return error("订单不存在");
        }
        System.out.println(orderId);
        return ordersService.payment(StpUtil.getLoginIdAsLong(), orderId);
    }
}
