package com.ruoyi.controller;

import cn.dev33.satoken.annotation.SaCheckLogin;
import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.domain.MApp;
import com.ruoyi.domain.MScene;
import com.ruoyi.service.MSceneService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author xuanxuan
 */
@Api(tags = "场景模块")
@RestController
@RequestMapping("/vrone/mobile/scenes")
@Anonymous
@SaCheckLogin
public class MSceneController extends BaseController {

    @Autowired
    private MSceneService sceneService;

    @PostMapping(value = "/add")
    @ApiOperation(value = "新增场景", notes = "传参为app（展厅实体）")
    public AjaxResult add(@RequestBody MScene scene) {
        if (!sceneService.insertScene(scene)) {
            return error("新增失败");
        }

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 201);
        ajaxResult.put("msg", "新增成功");
        return ajaxResult;
    }

    @PutMapping(value = "/edit")
    @ApiOperation(value = "修改场景", notes = "传参为scene（场景实体）")
    public AjaxResult edit(@RequestBody MScene scene) {
        if (!sceneService.updateScene(scene)) {
            return error("修改失败");
        }

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 201);
        ajaxResult.put("msg", "修改成功");
        return ajaxResult;
    }

    @PostMapping("/mySceneList/getListByUser")
    @ApiOperation(value = "根据用户id查询场景列表", notes = "userId（用户id）")
    public AjaxResult getListByUser(@RequestBody MScene scene) {

        List<MScene> list = sceneService.selectSceneListByUserId(scene.getUserId());
        return success(list);
    }

    @PostMapping("/listByApp/getListByApp")
    @ApiOperation(value = "根据展厅id查询场景列表", notes = "appId（展厅id）")
    public AjaxResult getListByApp(@RequestBody MScene scene) {

        List<MScene> list = sceneService.selectSceneListByAppId(scene.getAppId());
        return success(list);
    }

    @PostMapping(value = "/getInfo")
    @ApiOperation(value = "获取场景详细信息", notes = "传参为sceneId（场景id）")
    public AjaxResult getInfo(@RequestBody MScene scene) {
        return success(sceneService.selectSceneById(scene.getId()));
    }
}
