package com.ruoyi.controller;

import cn.dev33.satoken.annotation.SaCheckLogin;
import cn.dev33.satoken.stp.SaTokenInfo;
import cn.dev33.satoken.stp.StpUtil;
import cn.dev33.satoken.util.SaResult;
import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.common.config.RuoYiConfig;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.file.FileUploadUtils;
import com.ruoyi.common.utils.file.FileUtils;
import com.ruoyi.domain.MUser;
import com.ruoyi.domain.vo.MRechargeVO;
import com.ruoyi.framework.config.ServerConfig;
import com.ruoyi.service.RedisService;
import com.ruoyi.service.UserService;
import com.ruoyi.util.CodeUtils;
import com.ruoyi.util.EmailApi;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.HashMap;
import java.util.Map;

/**
 * @author xuanxuan
 */
@RestController
@RequestMapping("/user")
@Anonymous
public class UserController extends BaseController {

    @Autowired
    private ServerConfig serverConfig;

    @Autowired
    private UserService userService;

    @Autowired
    private RedisService redisService;

    @Autowired
    private EmailApi emailApi;


    //手机号账号注册
    @PostMapping("/register")
    public AjaxResult register(@RequestBody JSONObject jsonObject) {

        // 获取用户对象
        MUser user = jsonObject.getObject("user", MUser.class);

        // **1. 校验手机号是否为空**
        if (user.getPhone() == null || user.getPhone().trim().isEmpty()) {
            return AjaxResult.error("手机号不能为空");
        }

        // **2. 校验手机号是否为 11 位数字**
        if (!user.getPhone().matches("^\\d{11}$")) {
            return AjaxResult.error("手机号必须是11位数字");
        }

        // **3. 校验用户名和密码是否为空**
        if (user.getUserName() == null || user.getUserName().trim().isEmpty()) {
            return AjaxResult.error("用户名不能为空");
        }
        if (user.getPassword() == null || user.getPassword().trim().isEmpty()) {
            return AjaxResult.error("密码不能为空");
        }

        // **4. 判断用户是否已经存在**
        if (userService.isUserExist(user)) {
            return AjaxResult.error("手机号或邮箱已存在");
        }

        return AjaxResult.success(userService.registerUser(user));
    }

    // 手机号&邮箱密码登录
    @PostMapping("/login")
    public Map<String, Object> login(@RequestBody JSONObject jsonObject) {

        // 获取用户对象
        MUser user = jsonObject.getObject("user", MUser.class);
        if (user == null){
            return AjaxResult.error("用户名或密码为空");
        }
        // 调用登录方法
        boolean loginSuccess = userService.userLogin(user);

        if (loginSuccess) {
            // 第2步，获取 Token  相关参数
            SaTokenInfo tokenInfo = StpUtil.getTokenInfo();
            // 第3步，返回给前端
            return SaResult.data(tokenInfo);
        } else {
            return AjaxResult.error("用户名或密码错误");
        }
    }

    // 发送验证码
    @PostMapping("/sendCode")
    public Map<String, Object> sendCode(@RequestBody Map<String, String> request) {
        Map<String, Object> result = new HashMap<>();
        // 获取邮件地址
        String email = request.get("email");
        // 生成验证码
        String code = CodeUtils.generateCode();

        // 发送邮件
        emailApi.sendGeneralEmail("验证码",code,email);

        // 将验证码存储到 Redis
        redisService.saveCode(email, code);

        result.put("code", 200);
        result.put("message", "验证码已发送");
        return result;
    }

    // 邮箱验证码注册
    @PostMapping("/emailRegister")
    public AjaxResult emailRegister(@RequestBody JSONObject jsonObject) {

        // 获取用户对象
        MUser user = jsonObject.getObject("user", MUser.class);

        // 从 Redis 中获取验证码
        String savedCode = redisService.getCode(user.getEmail());

        if (savedCode == null || !savedCode.equals(user.getCode())) {
            return AjaxResult.error("message", "验证码错误或已过期");
        } else {
            // 验证码正确，完成注册逻辑
            boolean isRegistered = userService.emailRegister(user);
            if (!isRegistered) {
                // 注册失败，邮箱已存在
                return AjaxResult.error("message", "邮箱已存在");
            }

            // 删除 Redis 中的验证码
            redisService.deleteCode(user.getEmail());

        }

        return AjaxResult.success();
    }

    // 邮箱验证码登录
    @PostMapping("/emailLogin")
    public Map<String, Object> emailLogin(@RequestBody MUser user) {
        Map<String, Object> result = new HashMap<>();

        // 从 Redis 中获取验证码
        String savedCode = redisService.getCode(user.getEmail());

        if (savedCode == null || !savedCode.equals(user.getCode())) {
            result.put("code", 400);
            result.put("message", "邮箱或验证码错误");
        } else {
            // 验证码正确，完成登录逻辑
            boolean loginSuccess = userService.emailLogin(user);

            if (loginSuccess) {
                // 第2步，获取 Token  相关参数
                SaTokenInfo tokenInfo = StpUtil.getTokenInfo();
                // 第3步，返回给前端
                return SaResult.data(tokenInfo);
            } else {
                result.put("code", 401); // 登录失败
                result.put("message", "用户名或密码错误");
            }

            // 删除 Redis 中的验证码
            redisService.deleteCode(user.getEmail());

            result.put("code", 200);
            result.put("message", "登录成功");
        }

        return result;
    }

    //邮箱密码注册
    @RequestMapping("/emailPWDRegister")
    public AjaxResult emailPWDRegister(@RequestBody JSONObject jsonObject) {


        // 获取用户对象
        MUser user = jsonObject.getObject("user", MUser.class);

        if (user.getEmail() == null || user.getEmail().trim().isEmpty()) {
            return AjaxResult.error("邮箱不能为空");
        }

        //判断是否注册成功
        boolean registerSuccess = userService.emailPWDRegister(user);
        if (registerSuccess) {
            return AjaxResult.success("注册成功");
        } else {
            return AjaxResult.error("邮箱已存在");
        }
    }

    //查询登录状态
    @RequestMapping("/isLogin")
    public AjaxResult isLogin(){
        return  success(StpUtil.isLogin());
    }

    //注销登录
    @RequestMapping("/logout")
    public AjaxResult logout(){
        StpUtil.logout();
        return success();
    }

    @SaCheckLogin
    @PostMapping("/getUserInfo")
    public AjaxResult getUserInfo(@RequestBody MUser users){
        MUser user = userService.getUserInfo(users.getId());

        return AjaxResult.success(user);
    }


    @PostMapping("/update")
    @SaCheckLogin
    @ApiOperation(value = "更新个人信息", notes = "传参为user对象")
    public AjaxResult updateUserInfo(@RequestBody MUser user) {

        // 调用 Service 层更新数据
        if (userService.updateUserInfo(user)){
            return AjaxResult.success("更新成功");
        }else{
            return AjaxResult.error("更新失败");
        }
    }

    /**
     * 通用上传请求（单个）
     */
    @PostMapping("/upload")
    public AjaxResult uploadFile(MultipartFile file) throws Exception
    {
        try
        {
            // 上传文件路径
            String filePath = RuoYiConfig.getUploadPath();
            // 上传并返回新文件名称
            String fileName = FileUploadUtils.upload(filePath, file);
            String url = serverConfig.getUrl() + fileName;
            AjaxResult ajax = AjaxResult.success();
            ajax.put("url", url);
            ajax.put("fileName", fileName);
            ajax.put("newFileName", FileUtils.getName(fileName));
            ajax.put("originalFilename", file.getOriginalFilename());
            return AjaxResult.success(ajax);
        }
        catch (Exception e)
        {
            return AjaxResult.error(e.getMessage());
        }
    }


    @SaCheckLogin
    @PostMapping("/changePassword")
    @ApiOperation(value = "修改密码（旧密码方式）", notes = "传参为 userId, oldPassword, newPassword")
    public AjaxResult changePassword(@RequestBody JSONObject jsonObject) {

        Long userId = jsonObject.getLong("userId");
        String oldPassword = jsonObject.getString("oldPassword");
        String newPassword = jsonObject.getString("newPassword");

        if (userId == null || oldPassword == null || newPassword == null) {
            return AjaxResult.error("参数不能为空");
        }

        boolean result = userService.changePassword(userId, oldPassword, newPassword);
        if (result) {
            return AjaxResult.success("密码修改成功");
        } else {
            return AjaxResult.error("旧密码不正确或修改失败");
        }
    }

    @SaCheckLogin
    @PostMapping("/recharge")
    @ApiOperation(value = "余额充值", notes = "传参为rechargeVO对象")
    public AjaxResult recharge(@RequestBody MRechargeVO rechargeVO) {
        userService.recharge(rechargeVO);
        return AjaxResult.success("充值成功");
    }


}
