package com.ruoyi.service.impl;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.ruoyi.domain.MCart;
import com.ruoyi.service.MCartService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @author xuanxuan
 */
@Service
public class MCartServiceImpl implements MCartService {

    private static final String CART_PREFIX = "cart:"; // Redis Key前缀

    //把 Java 对象转换成 JSON
    private final ObjectMapper objectMapper = new ObjectMapper();

    @Autowired
    private StringRedisTemplate redisTemplate;

    /**
     * 新增商品到购物车
     *
     * @param cart 购物车对象
     * @return 结果
     */
    @Override
    public boolean addToCart(MCart cart) throws JsonProcessingException {
        String key = CART_PREFIX + cart.getUserId();
        String cartJson = objectMapper.writeValueAsString(cart);
        redisTemplate.opsForHash().put(key, cart.getId().toString(), cartJson);
        return true;
    }

    /**
     * 获取购物车列表
     *
     * @param userId 用户id
     * @return 结果
     */
    @Override
    public List<MCart> getCart(Integer userId) throws JsonProcessingException {
        String key = CART_PREFIX + userId;
        Map<Object, Object> entries = redisTemplate.opsForHash().entries(key);
        List<MCart> list = new ArrayList<>();
        for (Object entry : entries.values()) {
            list.add(objectMapper.readValue(entry.toString(), MCart.class));
        }
        return list;
    }

    /**
     * 删除购物车中的某个商品
     *
     * @param userId 用户id，模板id
     * @return 结果
     */
    @Override
    public boolean deleteFromCart(Integer userId, Integer id) {
        String key = CART_PREFIX + userId;
        redisTemplate.opsForHash().delete(key, String.valueOf(id));
        return true;
    }

    /**
     * 清空购物车
     *
     * @param userId 用户id
     * @return 结果
     */
    @Override
    public boolean clearCart(Integer userId) {
        String key = CART_PREFIX + userId;
        redisTemplate.delete(key);
        return true;
    }
}
