package com.ruoyi.service.impl;

import com.ruoyi.common.CommonUtils;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.domain.MScene;
import com.ruoyi.domain.MTemplate;
import com.ruoyi.mapper.MSceneMapper;
import com.ruoyi.mapper.MTemplateMapper;
import com.ruoyi.service.MSceneService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author xuanxuan
 */
@Service
public class MSceneServiceImpl implements MSceneService {

    @Autowired
    private MTemplateMapper templateMapper;

    @Autowired
    private MSceneMapper sceneMapper;

    /**
     * 新增场景
     *
     * @param scene 场景
     * @return 结果
     */
    @Override
    public boolean insertScene(MScene scene) {
        MTemplate template = templateMapper.selectTemplateById(scene.getTemplateId());
        // 获取配置文件
        String url = template.getUrl() + "/setting.json";
        String spotStr = CommonUtils.getContentByUrl(url, String.class);

        scene.setSpot(spotStr);
        scene.setType(template.getType());
        scene.setCreateTime(DateUtils.getNowDate());
        return sceneMapper.insertScene(scene) > 0;
    }

    /**
     * 修改场景
     *
     * @param scene 场景
     * @return 结果
     */
    @Override
    public boolean updateScene(MScene scene) {
        scene.setUpdateTime(DateUtils.getNowDate());
        return sceneMapper.updateScene(scene) > 0;
    }

    /**
     * 查询场景列表
     *
     * @param userId 用户id
     * @return 场景集合
     */
    @Override
    public List<MScene> selectSceneListByUserId(Long userId) {
        return sceneMapper.selectSceneListByUserId(userId);
    }

    /**
     * 查询场景列表
     *
     * @param appId 展厅id
     * @return 场景集合
     */
    @Override
    public List<MScene> selectSceneListByAppId(Long appId) {
        return sceneMapper.selectSceneListByAppId(appId);
    }

    /**
     * 查询场景
     *
     * @param id 场景主键
     * @return 场景
     */
    @Override
    public MScene selectSceneById(Long id) {
        return sceneMapper.selectSceneById(id);
    }
}
