package com.ruoyi.service.impl;

import cn.dev33.satoken.stp.StpUtil;
import com.ruoyi.domain.MTransactions;
import com.ruoyi.domain.vo.MRechargeVO;
import com.ruoyi.mapper.MTransactionsMapper;
import com.ruoyi.mapper.UserMapper;
import com.ruoyi.domain.MUser;
import com.ruoyi.service.UserService;
import com.ruoyi.util.PasswordUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;

/**
 * @author xuanxuan
 */
@Service
public class UserServiceImpl implements UserService {

    @Autowired
    private UserMapper userMapper;

    @Autowired
    private MTransactionsMapper mTransactionsMapper;

    //手机号注册
    @Override
    public boolean registerUser(MUser user) {

        // **2. 加密密码**
        String encryptedPassword = PasswordUtils.encryptPassword(user.getPassword());
        user.setPassword(encryptedPassword);


        return userMapper.registerUser(user)>0;
    }

    //手机号&邮箱密码登录
    @Override
    public boolean userLogin(MUser user) {
        // 根据用户名查询用户信息
        MUser users = userMapper.findByUsername(user);

        // 如果用户不存在，返回 false
        if (users == null) {
            return false;
        }
        //将用户信息存入sa-token
        StpUtil.login(users.getId());
        // 验证密码是否匹配
        return PasswordUtils.matchPassword(user.getPassword(), users.getPassword());
    }

    //邮箱验证码注册
    @Override
    public boolean emailRegister(MUser user) {
        // 根据邮箱查询用户信息
        MUser byUsername = userMapper.findByUsername(user);
        // 如果用户已经存在，返回 false
        if (byUsername != null) {
            return false;
        }
        return userMapper.emailRegister(user);
    }

    //邮箱验证码登录
    @Override
    public boolean emailLogin(MUser user) {
        // 根据邮箱查询用户信息
        MUser users = userMapper.findByUsername(user);

        // 如果用户不存在，返回 false
        if (users == null) {
            return false;
        }
        //将用户信息存入sa-token
        StpUtil.login(users.getId());

        // 如果邮箱已经存在，返回 true
        return true;
    }

    //邮箱密码注册
    @Override
    public boolean emailPWDRegister(MUser user) {
        // 根据用户名或者邮箱查询用户信息
        MUser byUsername = userMapper.findByUsername(user);

        // 如果用户已经存在，返回 false
        if (byUsername != null) {
            return false;
        }

        // **2. 加密密码**
        String encryptedPassword = PasswordUtils.encryptPassword(user.getPassword());
        user.setPassword(encryptedPassword);

        return userMapper.emailPWDRegister(user);
    }

    @Override
    public boolean isUserExist(MUser user) {

        // 根据用户名或手机号查找用户是否已存在
        MUser existingUser = userMapper.findByUsername(user);
        if (existingUser != null) {
            return true; // 用户已经存在
        }
        existingUser = userMapper.findByUsername(user);
        return existingUser != null; // 根据手机号检查
    }

    /**
     *
     * @param id 用户id
     * @return 用户对象
     */
    @Override
    public MUser getUserInfo(Long id) {
        return userMapper.selectUserById(id);
    }

    /**
     *
     * @param user 用户对象
     * @return 结果
     */
    @Override
    public boolean updateUserInfo(MUser user) {
        return userMapper.updateVrUser(user) > 0;
    }

    /**
     * 修改密码
     * @param userId 用户id
     * @param oldPassword 旧密码
     * @param newPassword 新密码
     * @return
     */
    @Override
    public boolean changePassword(Long userId, String oldPassword, String newPassword) {
        MUser user = userMapper.selectUserById(userId);
        if (user == null) {
            return false;
        }
        // 验证旧密码是否正确
        if (!PasswordUtils.matchPassword(oldPassword,user.getPassword())) {
            return false;
        }

        // 加密新密码并更新
        String encryptedPassword = PasswordUtils.encryptPassword(newPassword);
        user.setPassword(encryptedPassword);

        return userMapper.updateUser(user)>0;
    }

    @Transactional
    @Override
    public void recharge(MRechargeVO rechargeVO) {
        // 1. 插入支付记录

        MTransactions transaction = new MTransactions();
        transaction.setUserId(rechargeVO.getUserId());
        transaction.setOrderId(0L); // 没有订单，设为0
        transaction.setRecharge(rechargeVO.getAmount());//支付金额
        transaction.setPaymentMethod(rechargeVO.getPaymentMethod());
        transaction.setPaymentType(0); // 0代表余额充值
        transaction.setStatus(0); // 0成功
        transaction.setMoney(BigDecimal.ZERO);
        transaction.setMark("用户充值");

        mTransactionsMapper.insertRecharge(transaction);

        // 2. 更新用户余额和总充值
        userMapper.updateBalanceAndTotalMoney(rechargeVO);
    }

}
